@@ -26,8 +26,6 @@
 #include <glib/gi18n.h>
 #include <glib.h>
 #include <gtk/gtk.h>
-#include <libgnomeui/gnome-icon-lookup.h>
-#include <libgnomeui/gnome-icon-theme.h>
 
 #include "typedefs.h"
 #include "gth-file-view.h"
@@ -36,9 +34,8 @@
 #include "gthumb-enum-types.h"
 #include "file-utils.h"
 #include "file-data.h"
-#include "icons/pixbufs.h"
-#include "pixbuf-utils.h"
 #include "gth-sort-utils.h"
+#include "pixbuf-utils.h"
 
 
 enum {
@@ -55,16 +52,17 @@ enum {
 
 struct _GthFileViewListPrivate {
 	GtkTreeView    *tree_view;
+	GtkTreeModel   *filter_model;
 	GtkListStore   *list_store;
 	GthSortMethod   sort_method;
 	GtkSortType     sort_type;
 	GthViewMode     view_mode;
+	GthVisibleFunc  filter_func;
+	gpointer        filter_data;
 	int             max_image_size;
-	GnomeIconTheme *icon_theme;
 	gboolean        enable_thumbs;
 	gboolean        reorderable;
-	GdkPixbuf      *unknown_pixbuf_small;
-	GdkPixbuf      *unknown_pixbuf_big;
+	GHashTable     *scaled_pixbufs;
 };
 
 
@@ -137,14 +135,27 @@ get_sized_pixbuf (GthFileViewList *gfv_list,
 		  GdkPixbuf       *pixbuf)
 {
 	GdkPixbuf *result;
+	int        max_image_size;
 	int        x, y, w, h;
 
 	if (gfv_list->priv->max_image_size == 0)
 		return NULL;
 
-	result = gdk_pixbuf_new (GDK_COLORSPACE_RGB, TRUE, 8, 
-				 gfv_list->priv->max_image_size,
-				 gfv_list->priv->max_image_size);
+	/**/
+
+	max_image_size = gfv_list->priv->max_image_size;
+
+	if (! gfv_list->priv->enable_thumbs) {
+		int icon_width, icon_height;
+		gtk_icon_size_lookup_for_settings (gtk_widget_get_settings (GTK_WIDGET (gfv_list->priv->tree_view)),
+						   GTK_ICON_SIZE_MENU,
+						   &icon_width, &icon_height);
+		max_image_size = MAX (icon_width, icon_height);
+	}
+
+	result = gdk_pixbuf_new (GDK_COLORSPACE_RGB, TRUE, 8,
+				 max_image_size,
+				 max_image_size);
 	gdk_pixbuf_fill (result, 0x00000000);
 
 	if (pixbuf == NULL)
@@ -152,14 +163,46 @@ get_sized_pixbuf (GthFileViewList *gfv_list,
 
 	w = gdk_pixbuf_get_width (pixbuf);
 	h = gdk_pixbuf_get_height (pixbuf);
-	x = (gfv_list->priv->max_image_size - w) / 2; 
-	y = (gfv_list->priv->max_image_size - h) / 2; 
+	if (scale_keepping_ratio (&w, &h, max_image_size, max_image_size)) {
+		GdkPixbuf *try_pixbuf;
 
-	gdk_pixbuf_copy_area (pixbuf,
-			      0, 0,
-			      w, h,
-			      result,
-			      x, y);
+		/* look in the hash table. */
+
+		try_pixbuf = g_hash_table_lookup (gfv_list->priv->scaled_pixbufs, pixbuf);
+		if (try_pixbuf != NULL) {
+			g_object_unref (result);
+			result = try_pixbuf;
+			g_object_ref (G_OBJECT (result));
+			return result;
+		}
+		else {
+			GdkPixbuf *scaled;
+
+			scaled = gdk_pixbuf_scale_simple (pixbuf,
+							  w,
+							  h,
+							  GDK_INTERP_BILINEAR);
+			x = (max_image_size - w) / 2;
+			y = (max_image_size - h) / 2;
+			gdk_pixbuf_copy_area (scaled,
+					      0, 0,
+					      w, h,
+					      result,
+					      x, y);
+
+			g_hash_table_insert (gfv_list->priv->scaled_pixbufs, pixbuf, scaled);
+		}
+	}
+	else {
+		x = (max_image_size - w) / 2;
+		y = (max_image_size - h) / 2;
+
+		gdk_pixbuf_copy_area (pixbuf,
+				      0, 0,
+				      w, h,
+				      result,
+				      x, y);
+	}
 
 	return result;
 }
@@ -167,7 +210,7 @@ get_sized_pixbuf (GthFileViewList *gfv_list,
 
 static void
 gfv_insert (GthFileView  *file_view,
-	    int           pos, 
+	    int           pos,
 	    GdkPixbuf    *pixbuf,
 	    const char   *text,
 	    const char   *comment)
@@ -177,12 +220,9 @@ gfv_insert (GthFileView  *file_view,
 	GtkTreeIter      iter;
 	GdkPixbuf       *real_pixbuf;
 
-	if (! gfv_list->priv->enable_thumbs)
-		real_pixbuf = g_object_ref (gfv_list->priv->unknown_pixbuf_small);
-	else if (pixbuf == NULL)
-		real_pixbuf = get_sized_pixbuf (gfv_list, gfv_list->priv->unknown_pixbuf_big);
-	else
-		real_pixbuf = get_sized_pixbuf (gfv_list, pixbuf);
+	g_return_if_fail (pixbuf != NULL);
+
+	real_pixbuf = get_sized_pixbuf (gfv_list, pixbuf);
 
 	gtk_list_store_insert (list_store, &iter, pos);
 	gtk_list_store_set (list_store, &iter,
@@ -209,12 +249,9 @@ gfv_append (GthFileView  *file_view,
 	GtkTreePath     *path;
 	int              pos;
 
-	if (! gfv_list->priv->enable_thumbs)
-		real_pixbuf = g_object_ref (gfv_list->priv->unknown_pixbuf_small);
-	else if (pixbuf == NULL)
-		real_pixbuf = get_sized_pixbuf (gfv_list, gfv_list->priv->unknown_pixbuf_big);
-	else
-		real_pixbuf = get_sized_pixbuf (gfv_list, pixbuf);
+	g_return_val_if_fail (pixbuf != NULL, -1);
+
+	real_pixbuf = get_sized_pixbuf (gfv_list, pixbuf);
 
 	gtk_list_store_append (list_store, &iter);
 	gtk_list_store_set (list_store, &iter,
@@ -248,12 +285,9 @@ gfv_append_with_data (GthFileView  *file_view,
 	GtkTreePath     *path;
 	int              pos;
 
-	if (! gfv_list->priv->enable_thumbs)
-		real_pixbuf = g_object_ref (gfv_list->priv->unknown_pixbuf_small);
-	else if (pixbuf == NULL)
-		real_pixbuf = get_sized_pixbuf (gfv_list, gfv_list->priv->unknown_pixbuf_big);
-	else
-		real_pixbuf = get_sized_pixbuf (gfv_list, pixbuf);
+	g_return_val_if_fail (pixbuf != NULL, -1);
+
+	real_pixbuf = get_sized_pixbuf (gfv_list, pixbuf);
 
 	gtk_list_store_append (list_store, &iter);
 	gtk_list_store_set (list_store, &iter,
@@ -275,13 +309,15 @@ gfv_append_with_data (GthFileView  *file_view,
 
 
 static void
-gfv_remove (GthFileView  *file_view, 
-	    int           pos)
+gfv_remove (GthFileView *file_view,
+	    gpointer     data)
 {
 	GthFileViewList *gfv_list = (GthFileViewList *) file_view;
 	GtkTreeIter      iter;
 	GtkTreePath     *path;
+	int              pos;
 
+	pos = gth_file_view_find_image_from_data (file_view, data);
 	path = gtk_tree_path_new_from_indices (pos, -1);
 	if (! gtk_tree_model_get_iter (GTK_TREE_MODEL (gfv_list->priv->list_store),
 				       &iter,
@@ -303,7 +339,34 @@ gfv_clear (GthFileView  *file_view)
 	gtk_list_store_clear (gfv_list->priv->list_store);
 
 	if (GTK_WIDGET_REALIZED (gfv_list->priv->tree_view))
-                gtk_tree_view_scroll_to_point (GTK_TREE_VIEW (gfv_list->priv->tree_view), 0, 0);
+		gtk_tree_view_scroll_to_point (GTK_TREE_VIEW (gfv_list->priv->tree_view), 0, 0);
+}
+
+
+static gboolean
+get_list_store_iter_from_pos (GthFileViewList *gfv_list,
+			      int              pos,
+			      GtkTreeIter     *iter)
+{
+	GtkTreePath *filter_path;
+	GtkTreePath *store_path;
+	gboolean     retval = FALSE;
+
+	filter_path = gtk_tree_path_new_from_indices (pos, -1);
+	store_path = gtk_tree_model_filter_convert_path_to_child_path (GTK_TREE_MODEL_FILTER (gfv_list->priv->filter_model), filter_path);
+	gtk_tree_path_free (filter_path);
+
+	if (store_path == NULL)
+		return FALSE;
+
+	if (gtk_tree_model_get_iter (GTK_TREE_MODEL (gfv_list->priv->list_store),
+				       iter,
+				       store_path))
+		retval = TRUE;
+
+	gtk_tree_path_free (store_path);
+
+	return retval;
 }
 
 
@@ -314,51 +377,13 @@ gfv_set_image_pixbuf (GthFileView  *file_view,
 {
 	GthFileViewList *gfv_list = (GthFileViewList *) file_view;
 	GtkTreeIter      iter;
-	GtkTreePath     *path;
 
-	path = gtk_tree_path_new_from_indices (pos, -1);
-	if (! gtk_tree_model_get_iter (GTK_TREE_MODEL (gfv_list->priv->list_store),
-				       &iter,
-				       path)) {
-		gtk_tree_path_free (path);
+	if (! get_list_store_iter_from_pos (gfv_list, pos, &iter))
 		return;
-	}
-	gtk_tree_path_free (path);
 
 	gtk_list_store_set (gfv_list->priv->list_store, &iter,
 			    COLUMN_ICON, get_sized_pixbuf (gfv_list, pixbuf),
-                            -1);
-}
-
-
-static void
-gfv_set_unknown_pixbuf (GthFileView  *file_view,
-			int           pos)
-{
-	GthFileViewList *gfv_list = (GthFileViewList *) file_view;
-	GtkTreeIter      iter;
-	GtkTreePath     *path;
-	GdkPixbuf       *real_pixbuf;
-
-	path = gtk_tree_path_new_from_indices (pos, -1);
-	if (! gtk_tree_model_get_iter (GTK_TREE_MODEL (gfv_list->priv->list_store),
-				       &iter,
-				       path)) {
-		gtk_tree_path_free (path);
-		return;
-	}
-	gtk_tree_path_free (path);
-
-	if (! gfv_list->priv->enable_thumbs)
-		real_pixbuf = g_object_ref (gfv_list->priv->unknown_pixbuf_small);
-	else 
-		real_pixbuf = get_sized_pixbuf (gfv_list, gfv_list->priv->unknown_pixbuf_big);
-
-	gtk_list_store_set (gfv_list->priv->list_store, &iter,
-			    COLUMN_ICON, real_pixbuf,
-                            -1);
-
-	g_object_unref (real_pixbuf);
+			    -1);
 }
 
 
@@ -369,20 +394,13 @@ gfv_set_image_text (GthFileView  *file_view,
 {
 	GthFileViewList *gfv_list = (GthFileViewList *) file_view;
 	GtkTreeIter      iter;
-	GtkTreePath     *path;
 
-	path = gtk_tree_path_new_from_indices (pos, -1);
-	if (! gtk_tree_model_get_iter (GTK_TREE_MODEL (gfv_list->priv->list_store),
-				       &iter,
-				       path)) {
-		gtk_tree_path_free (path);
+	if (! get_list_store_iter_from_pos (gfv_list, pos, &iter))
 		return;
-	}
-	gtk_tree_path_free (path);
 
 	gtk_list_store_set (gfv_list->priv->list_store, &iter,
 			    COLUMN_NAME, text,
-                            -1);
+			    -1);
 }
 
 
@@ -396,7 +414,7 @@ gfv_get_image_text (GthFileView  *file_view,
 	char            *text = NULL;
 
 	path = gtk_tree_path_new_from_indices (pos, -1);
-	if (! gtk_tree_model_get_iter (GTK_TREE_MODEL (gfv_list->priv->list_store),
+	if (! gtk_tree_model_get_iter (GTK_TREE_MODEL (gfv_list->priv->filter_model),
 				       &iter,
 				       path)) {
 		gtk_tree_path_free (path);
@@ -404,9 +422,9 @@ gfv_get_image_text (GthFileView  *file_view,
 	}
 	gtk_tree_path_free (path);
 
-	gtk_tree_model_get (GTK_TREE_MODEL (gfv_list->priv->list_store), &iter,
-                            COLUMN_NAME, &text,
-                            -1);
+	gtk_tree_model_get (GTK_TREE_MODEL (gfv_list->priv->filter_model), &iter,
+			    COLUMN_NAME, &text,
+			    -1);
 
 	return text;
 }
@@ -419,20 +437,13 @@ gfv_set_image_comment (GthFileView  *file_view,
 {
 	GthFileViewList *gfv_list = (GthFileViewList *) file_view;
 	GtkTreeIter      iter;
-	GtkTreePath     *path;
 
-	path = gtk_tree_path_new_from_indices (pos, -1);
-	if (! gtk_tree_model_get_iter (GTK_TREE_MODEL (gfv_list->priv->list_store),
-				       &iter,
-				       path)) {
-		gtk_tree_path_free (path);
+	if (! get_list_store_iter_from_pos (gfv_list, pos, &iter))
 		return;
-	}
-	gtk_tree_path_free (path);
 
 	gtk_list_store_set (gfv_list->priv->list_store, &iter,
 			    COLUMN_COMMENT, comment,
-                            -1);
+			    -1);
 }
 
 
@@ -446,7 +457,7 @@ gfv_get_image_comment (GthFileView  *file_view,
 	char            *comment = NULL;
 
 	path = gtk_tree_path_new_from_indices (pos, -1);
-	if (! gtk_tree_model_get_iter (GTK_TREE_MODEL (gfv_list->priv->list_store),
+	if (! gtk_tree_model_get_iter (GTK_TREE_MODEL (gfv_list->priv->filter_model),
 				       &iter,
 				       path)) {
 		gtk_tree_path_free (path);
@@ -454,7 +465,7 @@ gfv_get_image_comment (GthFileView  *file_view,
 	}
 	gtk_tree_path_free (path);
 
-	gtk_tree_model_get (GTK_TREE_MODEL (gfv_list->priv->list_store), &iter,
+	gtk_tree_model_get (GTK_TREE_MODEL (gfv_list->priv->filter_model), &iter,
 			    COLUMN_COMMENT, &comment,
 			    -1);
 
@@ -466,13 +477,13 @@ static int
 gfv_get_images (GthFileView  *file_view)
 {
 	GthFileViewList *gfv_list = (GthFileViewList *) file_view;
-	GtkTreeModel    *model = GTK_TREE_MODEL (gfv_list->priv->list_store);
+	GtkTreeModel    *model = GTK_TREE_MODEL (gfv_list->priv->filter_model);
 	GtkTreeIter      iter;
 	int              len = 0;
 
 	if (! gtk_tree_model_get_iter_first (model, &iter))
 		return len;
-	
+
 	do {
 		len++;
 	} while (gtk_tree_model_iter_next (model, &iter));
@@ -485,13 +496,13 @@ static GList *
 gfv_get_list (GthFileView  *file_view)
 {
 	GthFileViewList *gfv_list = (GthFileViewList *) file_view;
-	GtkTreeModel    *model = GTK_TREE_MODEL (gfv_list->priv->list_store);
+	GtkTreeModel    *model = GTK_TREE_MODEL (gfv_list->priv->filter_model);
 	GtkTreeIter      iter;
 	GList           *list = NULL;
 
 	if (! gtk_tree_model_get_iter_first (model, &iter))
 		return NULL;
-	
+
 	do {
 		gpointer iter_data;
 
@@ -634,7 +645,7 @@ gfv_pos_is_selected (GthFileView     *file_view,
 	selection = gtk_tree_view_get_selection (gfv_list->priv->tree_view);
 
 	path = gtk_tree_path_new_from_indices (pos, -1);
-	if (! gtk_tree_model_get_iter (GTK_TREE_MODEL (gfv_list->priv->list_store),
+	if (! gtk_tree_model_get_iter (GTK_TREE_MODEL (gfv_list->priv->filter_model),
 				       &iter,
 				       path)) {
 		gtk_tree_path_free (path);
@@ -767,31 +778,24 @@ gfv_set_image_width (GthFileView     *file_view,
 
 static void
 gfv_set_image_data (GthFileView     *file_view,
-		    int              pos, 
+		    int              pos,
 		    gpointer         data)
 {
 	GthFileViewList *gfv_list = (GthFileViewList *) file_view;
 	GtkTreeIter      iter;
-	GtkTreePath     *path;
 
-	path = gtk_tree_path_new_from_indices (pos, -1);
-	if (! gtk_tree_model_get_iter (GTK_TREE_MODEL (gfv_list->priv->list_store),
-				       &iter,
-				       path)) {
-		gtk_tree_path_free (path);
+	if (! get_list_store_iter_from_pos (gfv_list, pos, &iter))
 		return;
-	}
-	gtk_tree_path_free (path);
 
 	gtk_list_store_set (gfv_list->priv->list_store, &iter,
 			    COLUMN_FILE_DATA, data,
-                            -1);
+			    -1);
 }
 
 
 static void
 gfv_set_image_data_full (GthFileView     *file_view,
-			 int              pos, 
+			 int              pos,
 			 gpointer         data,
 			 GtkDestroyNotify destroy)
 {
@@ -811,7 +815,7 @@ gfv_find_image_from_data (GthFileView     *file_view,
 
 	if (! gtk_tree_model_get_iter_first (model, &iter))
 		return -1;
-	
+
 	do {
 		gpointer iter_data;
 
@@ -838,7 +842,7 @@ gfv_get_image_data (GthFileView     *file_view,
 	FileData        *fdata;
 
 	path = gtk_tree_path_new_from_indices (pos, -1);
-	if (! gtk_tree_model_get_iter (GTK_TREE_MODEL (gfv_list->priv->list_store),
+	if (! gtk_tree_model_get_iter (GTK_TREE_MODEL (gfv_list->priv->filter_model),
 				       &iter,
 				       path)) {
 		gtk_tree_path_free (path);
@@ -846,9 +850,9 @@ gfv_get_image_data (GthFileView     *file_view,
 	}
 	gtk_tree_path_free (path);
 
-	gtk_tree_model_get (GTK_TREE_MODEL (gfv_list->priv->list_store), &iter,
-                            COLUMN_FILE_DATA, &fdata,
-                            -1);
+	gtk_tree_model_get (GTK_TREE_MODEL (gfv_list->priv->filter_model), &iter,
+			    COLUMN_FILE_DATA, &fdata,
+			    -1);
 	file_data_ref (fdata);
 
 	return fdata;
@@ -876,13 +880,8 @@ gfv_set_view_mode (GthFileView *file_view,
 
 	gfv_list->priv->view_mode = mode;
 
-	column = gtk_tree_view_get_column (gfv_list->priv->tree_view, 1);
-
-	/* FIXME
-        gtk_tree_view_column_set_visible (column, mode == GTH_VIEW_MODE_ALL);
-	*/
-
-        gtk_tree_view_column_set_visible (column, FALSE);
+	column = gtk_tree_view_get_column (gfv_list->priv->tree_view, 2);
+	gtk_tree_view_column_set_visible (column, FALSE /*mode == GTH_VIEW_MODE_ALL*/);
 }
 
 
@@ -896,7 +895,7 @@ gfv_get_view_mode (GthFileView *file_view)
 
 static void
 gfv_moveto (GthFileView *file_view,
-	    int          pos, 
+	    int          pos,
 	    double       yalign)
 {
 	GthFileViewList *gfv_list = (GthFileViewList *) file_view;
@@ -938,20 +937,20 @@ gfv_image_is_visible (GthFileView *file_view,
 
 	else if (image_rect.y < visible_rect.y)
 		visibility = GTH_VISIBILITY_PARTIAL_TOP;
-	
+
 	else if (image_rect.y + image_rect.height > visible_rect.y + visible_rect.height)
 		visibility = GTH_VISIBILITY_PARTIAL_BOTTOM;
-	
+
 	else
 		visibility = GTH_VISIBILITY_FULL;
-	
+
 	return visibility;
 }
 
 
 static int
-gfv_get_image_at (GthFileView *file_view, 
-		  int          x, 
+gfv_get_image_at (GthFileView *file_view,
+		  int          x,
 		  int          y)
 {
 	GthFileViewList *gfv_list = (GthFileViewList *) file_view;
@@ -982,11 +981,9 @@ gfv_get_first_visible (GthFileView *file_view)
 	GtkTreePath     *path;
 	int              pos;
 
-	gtk_tree_view_get_visible_rect (gfv_list->priv->tree_view,
-					&rect);
-
+	gtk_tree_view_get_visible_rect (gfv_list->priv->tree_view, &rect);
 	if (! gtk_tree_view_get_path_at_pos (gfv_list->priv->tree_view,
-					     0, 
+					     0,
 					     0,
 					     &path,
 					     NULL,
@@ -1009,10 +1006,9 @@ gfv_get_last_visible (GthFileView *file_view)
 	GtkTreePath     *path;
 	int              pos;
 
-	gtk_tree_view_get_visible_rect (gfv_list->priv->tree_view,
-					&rect);
+	gtk_tree_view_get_visible_rect (gfv_list->priv->tree_view, &rect);
 	if (! gtk_tree_view_get_path_at_pos (gfv_list->priv->tree_view,
-					     0, 
+					     0,
 					     rect.height - 1,
 					     &path,
 					     NULL,
@@ -1027,6 +1023,39 @@ gfv_get_last_visible (GthFileView *file_view)
 }
 
 
+static gboolean
+gfv_visible_func (GtkTreeModel *model,
+		  GtkTreeIter  *iter,
+		  gpointer      data)
+{
+	GthFileViewList *gfv_list = (GthFileViewList *) data;
+	FileData        *fdata;
+
+	if (gfv_list->priv->filter_func == NULL)
+		return TRUE;
+
+	gtk_tree_model_get (GTK_TREE_MODEL (gfv_list->priv->list_store), iter,
+			    COLUMN_FILE_DATA, &fdata,
+			    -1);
+
+	return (gfv_list->priv->filter_func) (gfv_list->priv->filter_data, fdata);
+}
+
+
+static void
+gfv_set_visible_func (GthFileView    *file_view,
+		      GthVisibleFunc  func,
+		      gpointer        data)
+{
+	GthFileViewList *gfv_list = (GthFileViewList *) file_view;
+
+	gfv_list->priv->filter_func = func;
+	gfv_list->priv->filter_data = data;
+
+	gtk_tree_model_filter_refilter (GTK_TREE_MODEL_FILTER (gfv_list->priv->filter_model));
+}
+
+
 static void
 gfv_sorted (GthFileView   *file_view,
 	    GthSortMethod  sort_method,
@@ -1079,7 +1108,7 @@ gfv_unsorted (GthFileView *file_view)
 
 
 static void
-gfv_image_activated (GthFileView *file_view, 
+gfv_image_activated (GthFileView *file_view,
 		     int          pos)
 {
 	GthFileViewList *gfv_list = (GthFileViewList *) file_view;
@@ -1092,7 +1121,7 @@ gfv_image_activated (GthFileView *file_view,
 
 
 static void
-gfv_set_cursor (GthFileView *file_view, 
+gfv_set_cursor (GthFileView *file_view,
 		int          pos)
 {
 	GthFileViewList *gfv_list = (GthFileViewList *) file_view;
@@ -1119,79 +1148,6 @@ gfv_get_cursor (GthFileView *file_view)
 }
 
 
-static GdkPixbuf *
-create_unknown_pixbuf (GthFileViewList *gfv_list, gboolean big)
-{
-	GnomeIconTheme *icon_theme = gfv_list->priv->icon_theme;
-	int             icon_width, icon_height, icon_size;
-	char           *icon_name;
-	char           *icon_path;
-	GdkPixbuf      *pixbuf = NULL;
-	int             width, height;
-
-	gtk_icon_size_lookup_for_settings (gtk_widget_get_settings (GTK_WIDGET (gfv_list->priv->tree_view)),
-                                           (big ? GTK_ICON_SIZE_DIALOG: GTK_ICON_SIZE_LARGE_TOOLBAR),
-                                           &icon_width, &icon_height);
-	icon_size = MAX (icon_width, icon_height);
-
-	icon_name = gnome_icon_lookup (icon_theme,
-				       NULL,
-				       NULL,
-				       NULL,
-				       NULL,
-				       "image/*",
-				       GNOME_ICON_LOOKUP_FLAGS_NONE,
-				       NULL);
-	icon_path = gnome_icon_theme_lookup_icon (icon_theme,
-						  icon_name,
-						  icon_size,
-						  NULL, 
-						  NULL);
-	g_free (icon_name);
-
-	if (icon_path != NULL) {
-		pixbuf = gdk_pixbuf_new_from_file (icon_path, NULL);
-		g_free (icon_path);
-	}
-
-	if (pixbuf == NULL) 
-		pixbuf = gdk_pixbuf_new_from_inline (-1, 
-						     dir_16_rgba, 
-						     FALSE, 
-						     NULL);
-
-	width = gdk_pixbuf_get_width (pixbuf);
-	height = gdk_pixbuf_get_height (pixbuf);
-	if (scale_keepping_ratio (&width, &height, icon_size, icon_size)) {
-		GdkPixbuf *scaled;
-		scaled = gdk_pixbuf_scale_simple (pixbuf,
-						  width,
-						  height,
-						  GDK_INTERP_BILINEAR);
-		g_object_unref (pixbuf);
-		pixbuf = scaled;
-	}
-
-	return pixbuf;
-}
-
-
-static void
-gfv_update_icon_theme (GthFileView *file_view)
-{
-	GthFileViewList *gfv_list = (GthFileViewList *) file_view;
-
-	if (gfv_list->priv->unknown_pixbuf_small != NULL) 
-		g_object_unref (gfv_list->priv->unknown_pixbuf_small);
-
-	if (gfv_list->priv->unknown_pixbuf_big != NULL) 
-		g_object_unref (gfv_list->priv->unknown_pixbuf_big);
-
-	gfv_list->priv->unknown_pixbuf_small = create_unknown_pixbuf (gfv_list, FALSE);
-	gfv_list->priv->unknown_pixbuf_big = create_unknown_pixbuf (gfv_list, TRUE);
-}
-
-
 /* DnD */
 
 
@@ -1220,7 +1176,7 @@ gfv_set_drag_dest_pos (GthFileView *file_view,
 		pos = GTK_TREE_VIEW_DROP_AFTER;
 	else if (pos == GTK_TREE_VIEW_DROP_INTO_OR_BEFORE)
 		pos = GTK_TREE_VIEW_DROP_BEFORE;
-	
+
 	gtk_tree_view_set_drag_dest_row (gfv_list->priv->tree_view,
 					 path,
 					 pos);
@@ -1242,7 +1198,7 @@ gfv_get_drag_dest_pos (GthFileView     *file_view,
 		*dest_pos = -1;
 		return;
 	}
-		
+
 	gtk_tree_view_get_drag_dest_row (gfv_list->priv->tree_view,
 					 &path,
 					 &pos);
@@ -1250,11 +1206,11 @@ gfv_get_drag_dest_pos (GthFileView     *file_view,
 	if (path != NULL) {
 		idx = gtk_tree_path_get_indices (path);
 		*dest_pos = idx[0];
-		if ((pos == GTK_TREE_VIEW_DROP_AFTER) 
+		if ((pos == GTK_TREE_VIEW_DROP_AFTER)
 		    || (pos == GTK_TREE_VIEW_DROP_INTO_OR_AFTER))
 			(*dest_pos)++;
 		gtk_tree_path_free (path);
-	} else 
+	} else
 		*dest_pos = -1;
 }
 
@@ -1303,6 +1259,29 @@ gfv_get_enable_search (GthFileView *file_view)
 /**/
 
 
+static void
+gh_unref_pixbuf (gpointer  key,
+		 gpointer  value,
+		 gpointer  user_data)
+{
+	g_object_unref (value);
+}
+
+
+static void
+gth_file_list_free_pixbufs (GthFileViewList *gfv_list)
+{
+	if (gfv_list->priv->scaled_pixbufs == NULL)
+		return;
+
+	g_hash_table_foreach (gfv_list->priv->scaled_pixbufs,
+			      gh_unref_pixbuf,
+			      NULL);
+	g_hash_table_destroy (gfv_list->priv->scaled_pixbufs);
+	gfv_list->priv->scaled_pixbufs = NULL;
+}
+
+
 static void
 gth_file_view_list_finalize (GObject *object)
 {
@@ -1311,13 +1290,10 @@ gth_file_view_list_finalize (GObject *object)
 
 	gfv_list = (GthFileViewList*) object;
 
-	g_object_unref (gfv_list->priv->icon_theme);
-	g_object_unref (gfv_list->priv->unknown_pixbuf_small);
-	g_object_unref (gfv_list->priv->unknown_pixbuf_big);
-
+	gth_file_list_free_pixbufs (gfv_list);
 	g_free (gfv_list->priv);
 
-        /* Chain up */
+	/* Chain up */
 	G_OBJECT_CLASS (parent_class)->finalize (object);
 }
 
@@ -1348,7 +1324,6 @@ gth_file_view_list_class_init (GthFileViewListClass *file_view_list_class)
 	file_view_class->remove               = gfv_remove;
 	file_view_class->clear                = gfv_clear;
 	file_view_class->set_image_pixbuf     = gfv_set_image_pixbuf;
-	file_view_class->set_unknown_pixbuf   = gfv_set_unknown_pixbuf;
 	file_view_class->set_image_text       = gfv_set_image_text;
 	file_view_class->get_image_text       = gfv_get_image_text;
 	file_view_class->set_image_comment    = gfv_set_image_comment;
@@ -1379,12 +1354,12 @@ gth_file_view_list_class_init (GthFileViewListClass *file_view_list_class)
 	file_view_class->get_image_at         = gfv_get_image_at;
 	file_view_class->get_first_visible    = gfv_get_first_visible;
 	file_view_class->get_last_visible     = gfv_get_last_visible;
+	file_view_class->set_visible_func     = gfv_set_visible_func;
 	file_view_class->sorted               = gfv_sorted;
 	file_view_class->unsorted             = gfv_unsorted;
 	file_view_class->image_activated      = gfv_image_activated;
 	file_view_class->set_cursor           = gfv_set_cursor;
 	file_view_class->get_cursor           = gfv_get_cursor;
-	file_view_class->update_icon_theme    = gfv_update_icon_theme;
 	file_view_class->set_drag_dest_pos    = gfv_set_drag_dest_pos;
 	file_view_class->get_drag_dest_pos    = gfv_get_drag_dest_pos;
 	file_view_class->set_reorderable      = gfv_set_reorderable;
@@ -1405,6 +1380,8 @@ gth_file_view_list_init (GthFileViewList *gfv_list)
 	priv->sort_method = GTH_SORT_METHOD_NONE;
 	priv->sort_type   = GTK_SORT_ASCENDING;
 	priv->reorderable = FALSE;
+
+	priv->scaled_pixbufs = g_hash_table_new (g_direct_hash, NULL);
 }
 
 
@@ -1424,19 +1401,19 @@ gth_file_view_list_get_type (void)
 			sizeof (GthFileViewList),
 			0,
 			(GInstanceInitFunc) gth_file_view_list_init
-                };
+		};
 
 		type = g_type_register_static (GTH_TYPE_FILE_VIEW,
 					       "GthFileViewList",
 					       &type_info,
 					       0);
-        }
+	}
 
 	return type;
 }
 
 
-static void 
+static void
 selection_changed_cb (GtkTreeSelection *selection,
 		      GthFileViewList  *gfv_list)
 {
@@ -1474,57 +1451,69 @@ cursor_changed_cb (GtkTreeView     *tree_view,
 static void
 add_columns (GtkTreeView *treeview)
 {
-	static char       *titles[] = {N_("Comment")};
 	GtkCellRenderer   *renderer;
 	GtkTreeViewColumn *column;
-	int                i, j;
 	GValue             value = { 0, };
-	
-	/* The Name column. */
+
+	/* The icon column */
+
 	column = gtk_tree_view_column_new ();
-	gtk_tree_view_column_set_title (column, _("Name"));
 
 	renderer = gtk_cell_renderer_pixbuf_new ();
 	gtk_tree_view_column_pack_start (column, renderer, FALSE);
 	gtk_tree_view_column_set_attributes (column, renderer,
-                                             "pixbuf", COLUMN_ICON,
-                                             NULL);
+					     "pixbuf", COLUMN_ICON,
+					     NULL);
+
+	gtk_tree_view_column_set_sizing (column, GTK_TREE_VIEW_COLUMN_AUTOSIZE);
+	gtk_tree_view_column_set_resizable (column, FALSE);
+	gtk_tree_view_column_set_expand (column, FALSE);
+
+	gtk_tree_view_append_column (treeview, column);
+
+	/* The name column */
+
+	column = gtk_tree_view_column_new ();
 
 	renderer = gtk_cell_renderer_text_new ();
-        g_value_init (&value, PANGO_TYPE_ELLIPSIZE_MODE);
-        g_value_set_enum (&value, PANGO_ELLIPSIZE_END);
-        g_object_set_property (G_OBJECT (renderer), "ellipsize", &value);
-        g_value_unset (&value);
-        	
-	gtk_tree_view_column_pack_start (column,
-					 renderer,
-					 TRUE);
+	gtk_tree_view_column_pack_start (column, renderer, TRUE);
 	gtk_tree_view_column_set_attributes (column, renderer,
-                                             "text", COLUMN_NAME,
-                                             NULL);
+					     "text", COLUMN_NAME,
+					     NULL);
+
+	g_value_init (&value, PANGO_TYPE_ELLIPSIZE_MODE);
+	g_value_set_enum (&value, PANGO_ELLIPSIZE_END);
+	g_object_set_property (G_OBJECT (renderer), "ellipsize", &value);
+	g_value_unset (&value);
 
-	/*gtk_tree_view_column_set_sizing (column, GTK_TREE_VIEW_COLUMN_AUTOSIZE);*/
-	/*
 	gtk_tree_view_column_set_sort_column_id (column, COLUMN_NAME);
-	gtk_tree_view_column_set_sort_column_id (column, COLUMN_PATH);
-	gtk_tree_view_column_set_sort_column_id (column, COLUMN_SIZE);
-	gtk_tree_view_column_set_sort_column_id (column, COLUMN_TIME);
-	*/
-	gtk_tree_view_append_column (GTK_TREE_VIEW (treeview), column);
+	gtk_tree_view_column_set_sizing (column, GTK_TREE_VIEW_COLUMN_AUTOSIZE);
+	gtk_tree_view_column_set_resizable (column, FALSE);
+	gtk_tree_view_column_set_expand (column, TRUE);
 
-	/* Other columns */
-	for (j = 0, i = COLUMN_COMMENT; i < NUMBER_OF_COLUMNS; i++, j++) {
-		renderer = gtk_cell_renderer_text_new ();
-		column = gtk_tree_view_column_new_with_attributes (_(titles[j]),
-								   renderer,
-								   "text", i,
-								   NULL);
+	gtk_tree_view_append_column (treeview, column);
 
-		gtk_tree_view_column_set_sizing (column, GTK_TREE_VIEW_COLUMN_AUTOSIZE);
-		gtk_tree_view_column_set_sort_column_id (column, i);
+	/* Comment column */
 
-		gtk_tree_view_append_column (treeview, column);
-	}
+	column = gtk_tree_view_column_new ();
+
+	renderer = gtk_cell_renderer_text_new ();
+	gtk_tree_view_column_pack_start (column, renderer, TRUE);
+	gtk_tree_view_column_set_attributes (column, renderer,
+					     "text", COLUMN_COMMENT,
+					     NULL);
+
+	g_value_init (&value, PANGO_TYPE_ELLIPSIZE_MODE);
+	g_value_set_enum (&value, PANGO_ELLIPSIZE_END);
+	g_object_set_property (G_OBJECT (renderer), "ellipsize", &value);
+	g_value_unset (&value);
+
+	gtk_tree_view_column_set_sort_column_id (column, COLUMN_COMMENT);
+	gtk_tree_view_column_set_sizing (column, GTK_TREE_VIEW_COLUMN_AUTOSIZE);
+	gtk_tree_view_column_set_resizable (column, FALSE);
+	gtk_tree_view_column_set_expand (column, TRUE);
+
+	gtk_tree_view_append_column (treeview, column);
 }
 
 
@@ -1576,7 +1565,7 @@ comp_func_exif_date (gconstpointer  ptr1,
 		     gconstpointer  ptr2)
 {
 	FileData *fd1 = (FileData *) ptr1, *fd2 = (FileData *) ptr2;
-	
+
 	if ((fd1 == NULL) || (fd2 == NULL))
 		return 0;
 
@@ -1607,15 +1596,7 @@ comp_func_comment (gconstpointer ptr1, gconstpointer ptr2)
 }
 
 
-static int
-comp_func_none (gconstpointer  ptr1,
-		gconstpointer  ptr2)
-{
-	return -1;
-}
-
-
-static GCompareFunc 
+static GCompareFunc
 get_compfunc_from_method (GthSortMethod sort_method)
 {
 	GCompareFunc func;
@@ -1637,10 +1618,10 @@ get_compfunc_from_method (GthSortMethod sort_method)
 		func = comp_func_comment;
 		break;
 	case GTH_SORT_METHOD_BY_EXIF_DATE:
-		func = comp_func_exif_date;	
-		break;	
+		func = comp_func_exif_date;
+		break;
 	default:
-		func = comp_func_none;
+		func = gth_sort_none;
 		break;
 	}
 
@@ -1649,9 +1630,9 @@ get_compfunc_from_method (GthSortMethod sort_method)
 
 
 static int
-default_sort_func (GtkTreeModel *model, 
-		   GtkTreeIter  *a, 
-		   GtkTreeIter  *b, 
+default_sort_func (GtkTreeModel *model,
+		   GtkTreeIter  *a,
+		   GtkTreeIter  *b,
 		   gpointer      user_data)
 {
 	GthFileViewList *gfv_list = user_data;
@@ -1659,8 +1640,8 @@ default_sort_func (GtkTreeModel *model,
 	GCompareFunc     cmp_func;
 	int              ret_val;
 
-        gtk_tree_model_get (model, a, COLUMN_FILE_DATA, &fdata1, -1);
-        gtk_tree_model_get (model, b, COLUMN_FILE_DATA, &fdata2, -1);
+	gtk_tree_model_get (model, a, COLUMN_FILE_DATA, &fdata1, -1);
+	gtk_tree_model_get (model, b, COLUMN_FILE_DATA, &fdata2, -1);
 
 	g_return_val_if_fail (fdata1 != NULL, 0);
 	g_return_val_if_fail (fdata2 != NULL, 0);
@@ -1682,7 +1663,7 @@ gth_file_view_list_new (guint image_width)
 	gfv_list = GTH_FILE_VIEW_LIST (g_object_new (GTH_TYPE_FILE_VIEW_LIST, NULL));
 	priv = gfv_list->priv;
 
-	priv->list_store = gtk_list_store_new (NUMBER_OF_COLUMNS, 
+	priv->list_store = gtk_list_store_new (NUMBER_OF_COLUMNS,
 					       G_TYPE_POINTER,
 					       GDK_TYPE_PIXBUF,
 					       G_TYPE_STRING,
@@ -1690,10 +1671,12 @@ gth_file_view_list_new (guint image_width)
 					       G_TYPE_STRING,
 					       G_TYPE_STRING,
 					       G_TYPE_STRING);
-
-	priv->tree_view = (GtkTreeView*) gtk_tree_view_new_with_model (GTK_TREE_MODEL (priv->list_store));
+	priv->filter_model =  gtk_tree_model_filter_new (GTK_TREE_MODEL (priv->list_store), NULL);
 	g_object_unref (priv->list_store);
 
+	priv->tree_view = (GtkTreeView*) gtk_tree_view_new_with_model (priv->filter_model);
+	g_object_unref (priv->filter_model);
+
 	gtk_tree_view_set_rules_hint (priv->tree_view, FALSE);
 	gtk_tree_view_set_headers_visible (priv->tree_view, FALSE);
 
@@ -1707,21 +1690,26 @@ gth_file_view_list_new (guint image_width)
 						 gfv_list, NULL);
 
 	gtk_tree_sortable_set_sort_func (GTK_TREE_SORTABLE (priv->list_store),
-                                         COLUMN_NAME, default_sort_func,
-                                         gfv_list, NULL);
+					 COLUMN_NAME, default_sort_func,
+					 gfv_list, NULL);
 	gtk_tree_sortable_set_sort_func (GTK_TREE_SORTABLE (priv->list_store),
-                                         COLUMN_PATH, default_sort_func,
-                                         gfv_list, NULL);
+					 COLUMN_PATH, default_sort_func,
+					 gfv_list, NULL);
 	gtk_tree_sortable_set_sort_func (GTK_TREE_SORTABLE (priv->list_store),
-                                         COLUMN_SIZE, default_sort_func,
-                                         gfv_list, NULL);
+					 COLUMN_SIZE, default_sort_func,
+					 gfv_list, NULL);
 	gtk_tree_sortable_set_sort_func (GTK_TREE_SORTABLE (priv->list_store),
-                                         COLUMN_TIME, default_sort_func,
-                                         gfv_list, NULL);
+					 COLUMN_TIME, default_sort_func,
+					 gfv_list, NULL);
 
 	selection = gtk_tree_view_get_selection (priv->tree_view);
 	gtk_tree_selection_set_mode (selection, GTK_SELECTION_MULTIPLE);
 
+	gtk_tree_model_filter_set_visible_func (GTK_TREE_MODEL_FILTER (priv->filter_model),
+						gfv_visible_func,
+						gfv_list,
+						NULL);
+
 	g_signal_connect (G_OBJECT (selection),
 			  "changed",
 			  G_CALLBACK (selection_changed_cb),
@@ -1735,12 +1723,5 @@ gth_file_view_list_new (guint image_width)
 			  G_CALLBACK (cursor_changed_cb),
 			  gfv_list);
 
-	/**/
-
-	priv->icon_theme = gnome_icon_theme_new ();
-	gnome_icon_theme_set_allow_svg (priv->icon_theme, TRUE);
-	priv->unknown_pixbuf_small = create_unknown_pixbuf (gfv_list, FALSE);
-	priv->unknown_pixbuf_big = create_unknown_pixbuf (gfv_list, TRUE);
-
 	return GTH_FILE_VIEW (gfv_list);
 }
