@@ -158,13 +158,6 @@ gfv_set_image_pixbuf (GthFileView  *file_view,
 }
 
 
-static void
-gfv_set_unknown_pixbuf (GthFileView  *file_view,
-			int           pos)
-{
-}
-
-
 static void
 gfv_set_image_text (GthFileView  *file_view,
 		    int           pos,
@@ -448,12 +441,6 @@ gfv_get_cursor (GthFileView *file_view)
 }
 
 
-static void
-gfv_update_icon_theme (GthFileView *file_view)
-{
-}
-
-
 static void
 gfv_set_no_image_text (GthFileView *file_view,
 		       const char  *text)
@@ -536,7 +523,6 @@ gth_file_view_class_init (GthFileViewClass *file_view_class)
 	file_view_class->remove               = gfv_remove;
 	file_view_class->clear                = gfv_clear;
 	file_view_class->set_image_pixbuf     = gfv_set_image_pixbuf;
-	file_view_class->set_unknown_pixbuf   = gfv_set_unknown_pixbuf;
 	file_view_class->set_image_text       = gfv_set_image_text;
 	file_view_class->get_image_text       = gfv_get_image_text;
 	file_view_class->set_image_comment    = gfv_set_image_comment;
@@ -573,7 +559,6 @@ gth_file_view_class_init (GthFileViewClass *file_view_class)
 	file_view_class->image_activated      = gfv_image_activated;
 	file_view_class->set_cursor           = gfv_set_cursor;
 	file_view_class->get_cursor           = gfv_get_cursor;
-	file_view_class->update_icon_theme    = gfv_update_icon_theme;
 	file_view_class->set_no_image_text    = gfv_set_no_image_text;
 	file_view_class->set_drag_dest_pos    = gfv_set_drag_dest_pos;
 	file_view_class->get_drag_dest_pos    = gfv_get_drag_dest_pos;
@@ -777,14 +762,6 @@ gth_file_view_set_image_pixbuf (GthFileView  *file_view,
 }
 
 
-void
-gth_file_view_set_unknown_pixbuf (GthFileView  *file_view,
-				  int           pos)
-{
-	GTH_FILE_VIEW_GET_CLASS (file_view)->set_unknown_pixbuf (file_view, pos);
-}
-
-
 void
 gth_file_view_set_image_text (GthFileView  *file_view,
 			      int           pos,
@@ -1085,13 +1062,6 @@ gth_file_view_get_cursor (GthFileView *file_view)
 }
 
 
-void
-gth_file_view_update_icon_theme (GthFileView *file_view)
-{
-	GTH_FILE_VIEW_GET_CLASS (file_view)->update_icon_theme (file_view);
-}
-
-
 void
 gth_file_view_set_no_image_text (GthFileView *file_view,
 				 const char  *text)
