@@ -6,7 +6,7 @@
 
 G_BEGIN_DECLS
 
-/* BOOL:BOOL (../libgthumb/gthumb-marshal.list:1) */
+/* BOOL:BOOL (./gthumb-marshal.list:1) */
 extern void gthumb_marshal_BOOLEAN__BOOLEAN (GClosure     *closure,
                                              GValue       *return_value,
                                              guint         n_param_values,
@@ -15,7 +15,7 @@ extern void gthumb_marshal_BOOLEAN__BOOLEAN (GClosure     *closure,
                                              gpointer      marshal_data);
 #define gthumb_marshal_BOOL__BOOL	gthumb_marshal_BOOLEAN__BOOLEAN
 
-/* BOOL:ENUM (../libgthumb/gthumb-marshal.list:2) */
+/* BOOL:ENUM (./gthumb-marshal.list:2) */
 extern void gthumb_marshal_BOOLEAN__ENUM (GClosure     *closure,
                                           GValue       *return_value,
                                           guint         n_param_values,
@@ -24,7 +24,7 @@ extern void gthumb_marshal_BOOLEAN__ENUM (GClosure     *closure,
                                           gpointer      marshal_data);
 #define gthumb_marshal_BOOL__ENUM	gthumb_marshal_BOOLEAN__ENUM
 
-/* BOOL:ENUM,ENUM (../libgthumb/gthumb-marshal.list:3) */
+/* BOOL:ENUM,ENUM (./gthumb-marshal.list:3) */
 extern void gthumb_marshal_BOOLEAN__ENUM_ENUM (GClosure     *closure,
                                                GValue       *return_value,
                                                guint         n_param_values,
@@ -33,7 +33,7 @@ extern void gthumb_marshal_BOOLEAN__ENUM_ENUM (GClosure     *closure,
                                                gpointer      marshal_data);
 #define gthumb_marshal_BOOL__ENUM_ENUM	gthumb_marshal_BOOLEAN__ENUM_ENUM
 
-/* BOOL:INT,POINTER (../libgthumb/gthumb-marshal.list:4) */
+/* BOOL:INT,POINTER (./gthumb-marshal.list:4) */
 extern void gthumb_marshal_BOOLEAN__INT_POINTER (GClosure     *closure,
                                                  GValue       *return_value,
                                                  guint         n_param_values,
@@ -42,7 +42,7 @@ extern void gthumb_marshal_BOOLEAN__INT_POINTER (GClosure     *closure,
                                                  gpointer      marshal_data);
 #define gthumb_marshal_BOOL__INT_POINTER	gthumb_marshal_BOOLEAN__INT_POINTER
 
-/* BOOL:VOID (../libgthumb/gthumb-marshal.list:5) */
+/* BOOL:VOID (./gthumb-marshal.list:5) */
 extern void gthumb_marshal_BOOLEAN__VOID (GClosure     *closure,
                                           GValue       *return_value,
                                           guint         n_param_values,
@@ -51,11 +51,11 @@ extern void gthumb_marshal_BOOLEAN__VOID (GClosure     *closure,
                                           gpointer      marshal_data);
 #define gthumb_marshal_BOOL__VOID	gthumb_marshal_BOOLEAN__VOID
 
-/* VOID:BOOL (../libgthumb/gthumb-marshal.list:6) */
+/* VOID:BOOL (./gthumb-marshal.list:6) */
 #define gthumb_marshal_VOID__BOOLEAN	g_cclosure_marshal_VOID__BOOLEAN
 #define gthumb_marshal_VOID__BOOL	gthumb_marshal_VOID__BOOLEAN
 
-/* VOID:ENUM,BOOLEAN (../libgthumb/gthumb-marshal.list:7) */
+/* VOID:ENUM,BOOLEAN (./gthumb-marshal.list:7) */
 extern void gthumb_marshal_VOID__ENUM_BOOLEAN (GClosure     *closure,
                                                GValue       *return_value,
                                                guint         n_param_values,
@@ -63,7 +63,7 @@ extern void gthumb_marshal_VOID__ENUM_BOOLEAN (GClosure     *closure,
                                                gpointer      invocation_hint,
                                                gpointer      marshal_data);
 
-/* VOID:ENUM,ENUM (../libgthumb/gthumb-marshal.list:8) */
+/* VOID:ENUM,ENUM (./gthumb-marshal.list:8) */
 extern void gthumb_marshal_VOID__ENUM_ENUM (GClosure     *closure,
                                             GValue       *return_value,
                                             guint         n_param_values,
@@ -71,10 +71,16 @@ extern void gthumb_marshal_VOID__ENUM_ENUM (GClosure     *closure,
                                             gpointer      invocation_hint,
                                             gpointer      marshal_data);
 
-/* VOID:FLOAT (../libgthumb/gthumb-marshal.list:9) */
+/* VOID:ENUM (./gthumb-marshal.list:9) */
+#define gthumb_marshal_VOID__ENUM	g_cclosure_marshal_VOID__ENUM
+
+/* VOID:FLOAT (./gthumb-marshal.list:10) */
 #define gthumb_marshal_VOID__FLOAT	g_cclosure_marshal_VOID__FLOAT
 
-/* VOID:INT,BOXED (../libgthumb/gthumb-marshal.list:10) */
+/* VOID:INT (./gthumb-marshal.list:11) */
+#define gthumb_marshal_VOID__INT	g_cclosure_marshal_VOID__INT
+
+/* VOID:INT,BOXED (./gthumb-marshal.list:12) */
 extern void gthumb_marshal_VOID__INT_BOXED (GClosure     *closure,
                                             GValue       *return_value,
                                             guint         n_param_values,
@@ -82,7 +88,15 @@ extern void gthumb_marshal_VOID__INT_BOXED (GClosure     *closure,
                                             gpointer      invocation_hint,
                                             gpointer      marshal_data);
 
-/* VOID:POINTER,POINTER (../libgthumb/gthumb-marshal.list:11) */
+/* VOID:INT,INT (./gthumb-marshal.list:13) */
+extern void gthumb_marshal_VOID__INT_INT (GClosure     *closure,
+                                          GValue       *return_value,
+                                          guint         n_param_values,
+                                          const GValue *param_values,
+                                          gpointer      invocation_hint,
+                                          gpointer      marshal_data);
+
+/* VOID:POINTER,POINTER (./gthumb-marshal.list:14) */
 extern void gthumb_marshal_VOID__POINTER_POINTER (GClosure     *closure,
                                                   GValue       *return_value,
                                                   guint         n_param_values,
@@ -90,10 +104,10 @@ extern void gthumb_marshal_VOID__POINTER_POINTER (GClosure     *closure,
                                                   gpointer      invocation_hint,
                                                   gpointer      marshal_data);
 
-/* VOID:STRING (../libgthumb/gthumb-marshal.list:12) */
+/* VOID:STRING (./gthumb-marshal.list:15) */
 #define gthumb_marshal_VOID__STRING	g_cclosure_marshal_VOID__STRING
 
-/* VOID:STRING,INT (../libgthumb/gthumb-marshal.list:13) */
+/* VOID:STRING,INT (./gthumb-marshal.list:16) */
 extern void gthumb_marshal_VOID__STRING_INT (GClosure     *closure,
                                              GValue       *return_value,
                                              guint         n_param_values,
@@ -101,7 +115,7 @@ extern void gthumb_marshal_VOID__STRING_INT (GClosure     *closure,
                                              gpointer      invocation_hint,
                                              gpointer      marshal_data);
 
-/* VOID:STRING,INT,BOXED (../libgthumb/gthumb-marshal.list:14) */
+/* VOID:STRING,INT,BOXED (./gthumb-marshal.list:17) */
 extern void gthumb_marshal_VOID__STRING_INT_BOXED (GClosure     *closure,
                                                    GValue       *return_value,
                                                    guint         n_param_values,
@@ -109,7 +123,7 @@ extern void gthumb_marshal_VOID__STRING_INT_BOXED (GClosure     *closure,
                                                    gpointer      invocation_hint,
                                                    gpointer      marshal_data);
 
-/* VOID:STRING,STRING (../libgthumb/gthumb-marshal.list:15) */
+/* VOID:STRING,STRING (./gthumb-marshal.list:18) */
 extern void gthumb_marshal_VOID__STRING_STRING (GClosure     *closure,
                                                 GValue       *return_value,
                                                 guint         n_param_values,
@@ -117,7 +131,7 @@ extern void gthumb_marshal_VOID__STRING_STRING (GClosure     *closure,
                                                 gpointer      invocation_hint,
                                                 gpointer      marshal_data);
 
-/* VOID:VOID (../libgthumb/gthumb-marshal.list:16) */
+/* VOID:VOID (./gthumb-marshal.list:19) */
 #define gthumb_marshal_VOID__VOID	g_cclosure_marshal_VOID__VOID
 
 G_END_DECLS
