@@ -29,7 +29,6 @@
 #define GTHUMB_STOCK_BRIGHTNESS_CONTRAST  "gthumb-brightness-contrast"
 #define GTHUMB_STOCK_CAMERA               "gthumb-camera"
 #define GTHUMB_STOCK_CATALOG              "gthumb-catalog"
-#define GTHUMB_STOCK_CDROM                "gthumb-cdrom"
 #define GTHUMB_STOCK_CHANGE_DATE          "gthumb-change-date"
 #define GTHUMB_STOCK_COLOR_BALANCE        "gthumb-color-balance"
 #define GTHUMB_STOCK_CROP                 "gthumb-crop"
@@ -37,20 +36,21 @@
 #define GTHUMB_STOCK_ENHANCE              "gthumb-enhance"
 #define GTHUMB_STOCK_EDIT_IMAGE           "gthumb-edit-image"
 #define GTHUMB_STOCK_FILM                 "gthumb-film"
+#define GTHUMB_STOCK_FILTER               "gthumb-filter"
 #define GTHUMB_STOCK_FLIP                 "gthumb-flip"
-#define GTHUMB_STOCK_FULLSCREEN           "gthumb-fullscreen"
 #define GTHUMB_STOCK_HISTOGRAM            "gthumb-histogram"
 #define GTHUMB_STOCK_HUE_SATURATION       "gthumb-hue-saturation"
 #define GTHUMB_STOCK_IMAGE                "gthumb-image"
 #define GTHUMB_STOCK_INDEX_IMAGE          "gthumb-index-image"
 #define GTHUMB_STOCK_INVERT               "gthumb-invert"
 #define GTHUMB_STOCK_LEVELS               "gthumb-levels"
+#define GTHUMB_STOCK_LIBRARY              "gthumb-library"
+#define GTHUMB_STOCK_METADATA             "gthumb-metadata"
 #define GTHUMB_STOCK_MIRROR               "gthumb-mirror"
 #define GTHUMB_STOCK_NEXT_IMAGE           "gthumb-next-image"
-#define GTHUMB_STOCK_NORMAL_VIEW          "gthumb-normal-view"
 #define GTHUMB_STOCK_POSTERIZE            "gthumb-posterize"
 #define GTHUMB_STOCK_PREVIOUS_IMAGE       "gthumb-previous-image"
-#define GTHUMB_STOCK_PROPERTIES           "gthumb-properties"
+#define GTHUMB_STOCK_REDEYE_REMOVAL       "gthumb-redeye-removal"
 #define GTHUMB_STOCK_REDUCE_COLORS        "gthumb-reduce-colors"
 #define GTHUMB_STOCK_RESET                "gthumb-reset"
 #define GTHUMB_STOCK_RESIZE               "gthumb-resize"
@@ -59,12 +59,12 @@
 #define GTHUMB_STOCK_ROTATE_90_CC         "gthumb-rotate-90-cc"
 #define GTHUMB_STOCK_SEARCH               "gthumb-search"
 #define GTHUMB_STOCK_SHOW_CATALOGS        "gthumb-show-catalogs"
-#define GTHUMB_STOCK_SHOW_FOLDERS         "gthumb-show-folders"
 #define GTHUMB_STOCK_SHOW_IMAGE           "gthumb-show-image"
 #define GTHUMB_STOCK_SLIDESHOW            "gthumb-slideshow"
 #define GTHUMB_STOCK_SWAP                 "gthumb-swap"
 #define GTHUMB_STOCK_THRESHOLD            "gthumb-threshold"
 #define GTHUMB_STOCK_TRANSFORM            "gthumb-transform"
+#define GTHUMB_STOCK_ZOOM_WIDTH		  "gthumb-zoom-width"
 
 
 void gthumb_stock_init (void);
