@@ -28,6 +28,7 @@
 #include <fcntl.h>
 #include <gtk/gtkmain.h>
 #include <gtk/gtksignal.h>
+#include <libgnomeui/gnome-thumbnail.h>
 #include <libgnomevfs/gnome-vfs-async-ops.h>
 #include <libgnomevfs/gnome-vfs-uri.h>
 #include <libgnomevfs/gnome-vfs-utils.h>
@@ -37,58 +38,66 @@
 #include "gthumb-marshal.h"
 #include "file-utils.h"
 #include "glib-utils.h"
+#include "gconf-utils.h"
 #include "gth-exif-utils.h"
 #include "pixbuf-utils.h"
+#include "preferences.h"
 
 
-#define REFRESH_RATE 5
+#define DEF_THUMB_SIZE        128
+#define THUMBNAIL_NORMAL_SIZE 128
+#define REFRESH_RATE          5
+
 G_LOCK_DEFINE_STATIC (pixbuf_loader_lock);
 
 
 struct _ImageLoaderPrivateData {
-	GdkPixbuf            *pixbuf;
-	GdkPixbufAnimation   *animation;
+	GdkPixbuf             *pixbuf;
+	GdkPixbufAnimation    *animation;
 
-	gboolean              as_animation; /* Whether to load the image in a
+	GnomeThumbnailFactory *thumb_factory;
+
+	gboolean               as_animation; /* Whether to load the image in a
 					     * GdkPixbufAnimation structure. */
 
-	GnomeVFSURI          *uri;
+	GnomeVFSURI           *uri;
+	const char            *mime_type;
 
-	GnomeVFSAsyncHandle  *info_handle;
+	GnomeVFSAsyncHandle   *info_handle;
 
-	GnomeVFSFileSize      bytes_read;
-	GnomeVFSFileSize      bytes_total;
+	GnomeVFSFileSize       bytes_read;
+	GnomeVFSFileSize       bytes_total;
 
-	gboolean              done;
-	gboolean              error;
-	gboolean              loader_done;
-	gboolean              interrupted;
-	gboolean              loading;
+	gboolean               done;
+	gboolean               error;
+	gboolean               loader_done;
+	gboolean               interrupted;
+	gboolean               loading;
 
-	GTimer               *timer;
-	int                   priority;
+	GTimer                *timer;
+	int                    priority;
 
-	DoneFunc              done_func;
-	gpointer              done_func_data;
+	DoneFunc               done_func;
+	gpointer               done_func_data;
 
-	gboolean              emit_signal;
+	gboolean               emit_signal;
 
-	guint                 check_id;
-	guint                 idle_id;
+	guint                  check_id;
+	guint                  idle_id;
 
-	GThread              *thread;
+	GThread               *thread;
 
-	GMutex               *yes_or_no;
+	GMutex                *yes_or_no;
 
-	gboolean              exit_thread;
-	GMutex               *exit_thread_mutex;
+	gboolean               exit_thread;
+	GMutex                *exit_thread_mutex;
 
-	gboolean              start_loading;
-	GMutex               *start_loading_mutex;
-	GCond                *start_loading_cond;
+	gboolean               start_loading;
+	GMutex                *start_loading_mutex;
+	GCond                 *start_loading_cond;
 
-	LoaderFunc            loader;
-	gpointer              loader_data;
+	LoaderFunc             loader;
+	gpointer               loader_data;
 };
 
 
@@ -171,11 +180,19 @@ image_loader_finalize (GObject *object)
         il = IMAGE_LOADER (object);
 	priv = il->priv;
 
+	if (priv->thumb_factory != NULL)
+		g_object_unref (priv->thumb_factory);
+
 	if (priv->idle_id != 0) {
 		g_source_remove (priv->idle_id);
 		priv->idle_id = 0;
 	}
 
+	if (priv->check_id != 0) {
+		g_source_remove (priv->check_id);
+		priv->check_id = 0;
+	}
+
 	image_loader_stop_common (il,
 				  (DoneFunc) image_loader_finalize__step2,
 				  object,
@@ -236,6 +253,7 @@ image_loader_init (ImageLoader *il)
 	il->priv = g_new0 (ImageLoaderPrivateData, 1);
 	priv = il->priv;
 
+	priv->thumb_factory = NULL;
 	priv->pixbuf = NULL;
 	priv->animation = NULL;
 	priv->uri = NULL;
@@ -271,7 +289,24 @@ image_loader_init (ImageLoader *il)
 	priv->loader = NULL;
 	priv->loader_data = NULL;
 
-	priv->thread = g_thread_create (load_image_thread, il, TRUE, NULL);
+	/*priv->thread = g_thread_create (load_image_thread, il, TRUE, NULL);*/
+
+	/* The g_thread_create function assigns a very large default stacksize for each
+	   thread (10 MB on FC6), which is probably excessive. 16k seems to be
+	   sufficient. To be conversative, we'll try 32k. Use g_thread_create_full to
+	   manually specify a small stack size. See Bug 310749 - Memory usage.
+	   This reduces the virtual memory requirements, and the "writeable/private"
+	   figure reported by "pmap -d". */
+
+	/* Update: 32k caused crashes with svg images. Boosting to 512k. Bug 410827. */
+
+	priv->thread = g_thread_create_full (load_image_thread,
+					     il,
+					     524288,
+					     TRUE,
+					     TRUE,
+					     G_THREAD_PRIORITY_NORMAL,
+					     NULL);
 }
 
 
@@ -309,12 +344,19 @@ image_loader_new (const gchar *path,
 {
 	ImageLoaderPrivateData *priv;
 	ImageLoader            *il;
+	int                     size;
 
 	il = IMAGE_LOADER (g_object_new (IMAGE_LOADER_TYPE, NULL));
 	priv = (ImageLoaderPrivateData*) il->priv;
 
 	priv->as_animation = as_animation;
-	image_loader_set_path (il, path);
+	image_loader_set_path (il, path, NULL);
+
+	size = eel_gconf_get_integer (PREF_THUMBNAIL_SIZE, DEF_THUMB_SIZE);
+	if (size <= THUMBNAIL_NORMAL_SIZE)
+		priv->thumb_factory = gnome_thumbnail_factory_new (GNOME_THUMBNAIL_SIZE_NORMAL);
+	else
+		priv->thumb_factory = gnome_thumbnail_factory_new (GNOME_THUMBNAIL_SIZE_LARGE);
 
 	return G_OBJECT (il);
 }
@@ -336,7 +378,8 @@ image_loader_set_loader (ImageLoader *il,
 
 void
 image_loader_set_path (ImageLoader *il,
-		       const char  *path)
+		       const char  *path,
+		       const char  *mime_type)
 {
 	ImageLoaderPrivateData *priv;
 
@@ -346,6 +389,10 @@ image_loader_set_path (ImageLoader *il,
 
 	g_mutex_lock (priv->yes_or_no);
 
+	if (mime_type == NULL)
+		mime_type = get_file_mime_type (path, eel_gconf_get_boolean (PREF_FAST_FILE_TYPE, TRUE));
+	priv->mime_type = mime_type;
+
 	if (priv->uri != NULL) {
 		gnome_vfs_uri_unref (priv->uri);
 		priv->uri = NULL;
@@ -359,7 +406,8 @@ image_loader_set_path (ImageLoader *il,
 
 void
 image_loader_set_uri (ImageLoader       *il,
-		      const GnomeVFSURI *uri)
+		      const GnomeVFSURI *uri,
+		      const char        *mime_type)
 {
 	ImageLoaderPrivateData *priv;
 
@@ -369,6 +417,8 @@ image_loader_set_uri (ImageLoader       *il,
 
 	g_mutex_lock (priv->yes_or_no);
 
+	priv->mime_type = mime_type;
+
 	if (priv->uri != NULL) {
 		gnome_vfs_uri_unref (priv->uri);
 		priv->uri = NULL;
@@ -407,23 +457,22 @@ image_loader_set_pixbuf (ImageLoader *il,
 	g_mutex_unlock (priv->yes_or_no);
 }
 
+
 static void
 image_loader_sync_pixbuf (ImageLoader *il)
 {
 	GdkPixbuf              *pixbuf;
 	GdkPixbuf              *temp;
 	ImageLoaderPrivateData *priv;
-	ExifShort				orientation;
-	GthTransform			transform;
+	ExifShort		orientation;
+	GthTransform		transform;
 
 	g_return_if_fail (il != NULL);
 
 	priv = il->priv;
 
 	orientation = get_exif_tag_short (image_loader_get_path(il), EXIF_TAG_ORIENTATION);
-	transform =  (orientation >= 1 && orientation <= 8 ?
-						orientation :
-						GTH_TRANSFORM_NONE);
+	transform = (orientation >= 1 && orientation <= 8 ? orientation : GTH_TRANSFORM_NONE);
 
 	g_mutex_lock (priv->yes_or_no);
 
@@ -587,19 +636,14 @@ load_image_thread (void *thread_data)
 		animation = NULL;
 		if (path != NULL) {
 			if (priv->loader != NULL)
-				animation = (*priv->loader) (path, &error, priv->loader_data);
-			else {
-				if (image_is_gif__accurate (path))
-					animation = gdk_pixbuf_animation_new_from_file (path, &error);
-				else {
-					GdkPixbuf *pixbuf;
-					pixbuf = gdk_pixbuf_new_from_file (path, &error);
-					if (pixbuf != NULL) {
-						animation = gdk_pixbuf_non_anim_new (pixbuf);
-						g_object_unref (pixbuf);
-					}
-				}
-			}
+				animation = (*priv->loader) (path, priv->mime_type, &error, priv->loader_data);
+        		else
+		                animation = gth_pixbuf_animation_new_from_uri (path,
+									       &error,
+									       0,
+									       0,
+									       priv->thumb_factory,
+									       priv->mime_type);
 		}
 
 		G_UNLOCK (pixbuf_loader_lock);
@@ -817,23 +861,6 @@ image_loader_start (ImageLoader *il)
 /* -- image_loader_stop -- */
 
 
-
-static void
-close_info_cb (GnomeVFSAsyncHandle *handle,
-	       GnomeVFSResult       result,
-	       gpointer             data)
-{
-	/* FIXME */
-
-	/*
-	ImageLoader            *il = data;
-	ImageLoaderPrivateData *priv = il->priv;
-	priv->info_handle = NULL;
-	image_loader_stop__final_step (il);
-	*/
-}
-
-
 static void
 image_loader_stop_common (ImageLoader *il,
 			  DoneFunc     done_func,
@@ -853,7 +880,7 @@ image_loader_stop_common (ImageLoader *il,
 	priv->emit_signal = emit_sig;
 
 	if (priv->info_handle != NULL)
-		gnome_vfs_async_close (priv->info_handle, close_info_cb, il);
+		gnome_vfs_async_cancel (priv->info_handle);
 
 	priv->info_handle = NULL;
 	image_loader_stop__final_step (il, use_idle_cb);
@@ -983,9 +1010,8 @@ gchar *
 image_loader_get_path (ImageLoader *il)
 {
 	ImageLoaderPrivateData *priv;
-	char                   *path;
-        char                   *esc_path;
 	GnomeVFSURI            *uri;
+	char                   *path;
 
 	g_return_val_if_fail (il != NULL, 0);
 	priv = il->priv;
@@ -998,15 +1024,12 @@ image_loader_get_path (ImageLoader *il)
 	}
 
 	uri = gnome_vfs_uri_dup (priv->uri);
-
-        path = gnome_vfs_uri_to_string (uri, GNOME_VFS_URI_HIDE_TOPLEVEL_METHOD);
-        esc_path = gnome_vfs_unescape_string (path, NULL);
-        g_free (path);
+        path = gnome_vfs_uri_to_string (uri, GNOME_VFS_URI_HIDE_NONE);
 	gnome_vfs_uri_unref (uri);
 
 	g_mutex_unlock (priv->yes_or_no);
 
-        return esc_path;
+        return path;
 }
 
 
