@@ -656,13 +656,6 @@ comp_func_size (gconstpointer a, gconstpointer b)
 }
 
 
-static int
-comp_func_none (gconstpointer a, gconstpointer b)
-{
-	return -1;
-}
-
-
 static GCompareFunc
 get_sortfunc (CatalogWebExporter *ce)
 {
@@ -688,10 +681,10 @@ get_sortfunc (CatalogWebExporter *ce)
 		func = comp_func_exif_date;
 		break;
 	case GTH_SORT_METHOD_NONE:
-		func = comp_func_none;
+		func = gth_sort_none;
 		break;
 	default:
-		func = comp_func_none;
+		func = gth_sort_none;
 		break;
 	}
 
@@ -1760,16 +1753,19 @@ copy_exif_from_orig_and_reset_orientation (const char *src_filename,
 {
 	JPEGData     *jdata_src, *jdata_dest;
 	ExifData     *edata_src;
+	char         *local_src_filename = NULL;
+	char         *local_dest_filename = NULL;
+	gboolean      is_local;
 
-	src_filename = get_file_path_from_uri (src_filename);
-	if (src_filename == NULL)
+	is_local = is_local_file (dest_filename);
+
+	local_src_filename = obtain_local_file (src_filename);
+	local_dest_filename = obtain_local_file (dest_filename);
+
+	if ((local_src_filename == NULL) || (local_dest_filename == NULL))
 		return;
 
-	dest_filename = get_file_path_from_uri (dest_filename);
-	if (dest_filename == NULL)
-		return;
-
-	jdata_src = jpeg_data_new_from_file (src_filename);
+	jdata_src = jpeg_data_new_from_file (local_src_filename);
 	if (jdata_src == NULL)
 		return;
 
@@ -1779,7 +1775,7 @@ copy_exif_from_orig_and_reset_orientation (const char *src_filename,
 		return;
 	}
 
-	jdata_dest = jpeg_data_new_from_file (dest_filename);
+	jdata_dest = jpeg_data_new_from_file (local_dest_filename);
 	if (jdata_dest == NULL)
 		return;
 
@@ -1802,6 +1798,12 @@ copy_exif_from_orig_and_reset_orientation (const char *src_filename,
 	exif_data_unref (edata_src);
 	jpeg_data_unref (jdata_src);
 	jpeg_data_unref (jdata_dest);
+
+        if (!is_local)
+		copy_cache_file_to_remote_uri (local_dest_filename, dest_filename);
+
+	g_free (local_src_filename);
+	g_free (local_dest_filename);
 }
 
 
@@ -2077,7 +2079,7 @@ load_next_file (CatalogWebExporter *ce)
 
 	} else {
 		char *filename = IMAGE_DATA (ce->file_to_load->data)->src_filename;
-		image_loader_set_path (ce->iloader, filename);
+		image_loader_set_path (ce->iloader, filename, NULL);
 		image_loader_start (ce->iloader);
 	}
 }
@@ -2248,8 +2250,7 @@ export__copy_image (CatalogWebExporter *ce)
 		if (transform > 1)
 			apply_transformation_jpeg(GTK_WINDOW (ce->window),
 						  dest_filename,
-						  transform,
-						  FALSE);
+						  transform);
 	}
 }
 
@@ -2612,7 +2613,8 @@ catalog_web_exporter_export (CatalogWebExporter *ce)
 
 	ce->file_to_load = ce->file_list;
 	image_loader_set_path (ce->iloader,
-			       IMAGE_DATA (ce->file_to_load->data)->src_filename);
+			       IMAGE_DATA (ce->file_to_load->data)->src_filename,
+			       NULL);
 	image_loader_start (ce->iloader);
 }
 
