@@ -3,7 +3,7 @@
 /*
  *  GThumb
  *
- *  Copyright (C) 2001 The Free Software Foundation, Inc.
+ *  Copyright (C) 2001-2005 The Free Software Foundation, Inc.
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -22,14 +22,19 @@
 
 #include <config.h>
 #include <time.h>
+
+#include <glib/gi18n.h>
 #include <gtk/gtk.h>
 #include <libgnome/gnome-help.h>
 #include <libgnomeui/gnome-dateedit.h>
 #include <glade/glade.h>
+
+#include "comments.h"
 #include "file-data.h"
 #include "gth-exif-utils.h"
 #include "file-utils.h"
-#include "gthumb-window.h"
+#include "gth-utils.h"
+#include "gth-window.h"
 #include "main.h"
 
 
@@ -37,17 +42,25 @@
 
 
 typedef struct {
-	GThumbWindow *window;
+	GthWindow    *window;
 	GladeXML     *gui;
 
 	GtkWidget    *dialog;
+	GtkWidget    *ok_button;
+
+	GtkWidget    *cd_last_modified_checkbutton;
+	GtkWidget    *cd_comment_checkbutton;
+
 	GtkWidget    *cd_following_date_radiobutton;
 	GtkWidget    *cd_created_radiobutton;
 	GtkWidget    *cd_current_radiobutton;
 	GtkWidget    *cd_exif_radiobutton;
-
+	GtkWidget    *cd_adjust_timezone_radiobutton;
 	GtkWidget    *cd_dateedit;
 
+	GtkWidget    *cd_timezone_box;
+	GtkWidget    *cd_timezone_spinbutton;
+
 	GList        *file_list;
 } DialogData;
 
@@ -63,8 +76,6 @@ destroy_cb (GtkWidget  *widget,
 }
 
 
-#ifdef HAVE_LIBEXIF
-
 static gboolean
 exif_time_available (DialogData *data)
 {
@@ -82,8 +93,6 @@ exif_time_available (DialogData *data)
 }
 
 
-#endif /* HAVE_LIBEXIF */
-
 #define is_active(x) (gtk_toggle_button_get_active (GTK_TOGGLE_BUTTON (x)))
 
 
@@ -91,42 +100,91 @@ static void
 ok_clicked (GtkWidget  *button, 
 	    DialogData *data)
 {
-	GList  *scan;
+	GList  *scan, *file_list = NULL;
 	time_t  mtime = 0;
+	time_t  comment_time = 0;
 
-	if (is_active (data->cd_following_date_radiobutton)) 
+	if (is_active (data->cd_following_date_radiobutton)) {
 		mtime = gnome_date_edit_get_time (GNOME_DATE_EDIT (data->cd_dateedit));
-	else if (is_active (data->cd_current_radiobutton)) 
+		comment_time = mtime;
+	} else if (is_active (data->cd_current_radiobutton)) {
 		time (&mtime);
+		comment_time = mtime;
+	}
 	
 	all_windows_remove_monitor ();
 
 	for (scan = data->file_list; scan; scan = scan->next) {
 		FileData *fdata = scan->data;
-		
-		if (is_active (data->cd_created_radiobutton)) 
+
+		if (is_active (data->cd_created_radiobutton)) {
 			mtime = get_file_ctime (fdata->path);
-#ifdef HAVE_LIBEXIF
-		else if (is_active (data->cd_exif_radiobutton)) 
+			comment_time = mtime;
+		} else if (is_active (data->cd_exif_radiobutton)) {
 			mtime = get_exif_time (fdata->path);
-#endif /* HAVE_LIBEXIF */
-		
-		if (mtime > 0) 
+			comment_time = mtime;
+		} else if (is_active (data->cd_adjust_timezone_radiobutton)) {
+			time_t tz;
+
+			comment_time = 0;
+			tz = (int) gtk_spin_button_get_value (GTK_SPIN_BUTTON (data->cd_timezone_spinbutton)) * (60 * 60);
+			if (is_active (data->cd_comment_checkbutton)) {
+				CommentData *cdata;
+				cdata = comments_load_comment (fdata->path, TRUE);
+				if (cdata != NULL) {
+					comment_time = cdata->time + tz;
+					comment_data_free (cdata);
+				}
+			}
+			if (is_active (data->cd_last_modified_checkbutton)) 
+				mtime = get_file_mtime (fdata->path) + tz;
+		}
+			
+		if ((mtime <= 0) && (comment_time <= 0))
+			continue;
+
+		if (is_active (data->cd_last_modified_checkbutton))
 			set_file_mtime (fdata->path, mtime);
+
+		if (is_active (data->cd_comment_checkbutton)) {
+			CommentData *cdata;
+			cdata = comments_load_comment (fdata->path, TRUE);
+			if (cdata == NULL)
+				cdata = comment_data_new ();
+			cdata->time = comment_time;
+			comments_save_comment (fdata->path, cdata);
+			comment_data_free (cdata);
+		}
+
+		file_list = g_list_prepend (file_list, fdata->path);
 	}
 
-	all_windows_notify_files_changed (data->file_list);
+	all_windows_notify_files_changed (file_list);
+	g_list_free (file_list);
+
 	all_windows_add_monitor ();
 	
 	gtk_widget_destroy (data->dialog);
 }
 
 
+static void
+update_sensitivity (DialogData *data)
+{
+	gtk_widget_set_sensitive (data->ok_button,
+				  gtk_toggle_button_get_active (GTK_TOGGLE_BUTTON (data->cd_last_modified_checkbutton))
+				  || gtk_toggle_button_get_active (GTK_TOGGLE_BUTTON (data->cd_comment_checkbutton)));
+		
+	gtk_widget_set_sensitive (data->cd_dateedit, gtk_toggle_button_get_active (GTK_TOGGLE_BUTTON (data->cd_following_date_radiobutton)));
+	gtk_widget_set_sensitive (data->cd_timezone_box, gtk_toggle_button_get_active (GTK_TOGGLE_BUTTON (data->cd_adjust_timezone_radiobutton)));
+}
+
+
 static void
 radio_button_clicked (GtkWidget  *button, 
 		      DialogData *data)
 {
-	gtk_widget_set_sensitive (data->cd_dateedit, gtk_toggle_button_get_active (GTK_TOGGLE_BUTTON (data->cd_following_date_radiobutton)));
+	update_sensitivity (data);
 }
 
 
@@ -136,44 +194,19 @@ static void
 help_cb (GtkWidget  *widget, 
 	 DialogData *data)
 {
-	GError *err;
-
-	err = NULL;  
-	gnome_help_display ("gthumb", "gthumb-change-date", &err);
-	
-	if (err != NULL) {
-		GtkWidget *dialog;
-		
-		dialog = gtk_message_dialog_new (GTK_WINDOW (data->dialog),
-						 0,
-						 GTK_MESSAGE_ERROR,
-						 GTK_BUTTONS_CLOSE,
-						 _("Could not display help: %s"),
-						 err->message);
-		
-		g_signal_connect (G_OBJECT (dialog), "response",
-				  G_CALLBACK (gtk_widget_destroy),
-				  NULL);
-		
-		gtk_window_set_resizable (GTK_WINDOW (dialog), FALSE);
-		
-		gtk_widget_show (dialog);
-		
-		g_error_free (err);
-	}
+	gthumb_display_help (GTK_WINDOW (data->dialog), "gthumb-change-date");
 }
 
 
 void
-dlg_change_date (GThumbWindow *window)
+dlg_change_date (GthWindow *window)
 {
 	DialogData  *data;
 	GtkWidget   *cancel_button;
-	GtkWidget   *ok_button;
 	GtkWidget   *help_button;
 	GList       *list;
 
-	list = gth_file_list_get_selection_as_fd (window->file_list);
+	list = gth_window_get_file_list_selection_as_fd (window);
 	if (list == NULL) {
 		g_warning ("No file selected.");
 		return;
@@ -198,26 +231,32 @@ dlg_change_date (GThumbWindow *window)
 	/* Get the widgets. */
 
 	data->dialog = glade_xml_get_widget (data->gui, "change_date_dialog");
+
+	data->cd_last_modified_checkbutton = glade_xml_get_widget (data->gui, "cd_last_modified_checkbutton");
+	data->cd_comment_checkbutton = glade_xml_get_widget (data->gui, "cd_comment_checkbutton");
+
 	data->cd_following_date_radiobutton = glade_xml_get_widget (data->gui, "cd_following_date_radiobutton");
 	data->cd_created_radiobutton = glade_xml_get_widget (data->gui, "cd_created_radiobutton");
 	data->cd_current_radiobutton = glade_xml_get_widget (data->gui, "cd_current_radiobutton");
 	data->cd_exif_radiobutton = glade_xml_get_widget (data->gui, "cd_exif_radiobutton");
+	data->cd_adjust_timezone_radiobutton = glade_xml_get_widget (data->gui, "cd_adjust_timezone_radiobutton");
 	data->cd_dateedit = glade_xml_get_widget (data->gui, "cd_dateedit");
 
+	data->cd_timezone_box = glade_xml_get_widget (data->gui, "cd_timezone_box");
+	data->cd_timezone_spinbutton = glade_xml_get_widget (data->gui, "cd_timezone_spinbutton");
+
 	cancel_button = glade_xml_get_widget (data->gui, "cd_cancel_button");
-	ok_button = glade_xml_get_widget (data->gui, "cd_ok_button");
+	data->ok_button = glade_xml_get_widget (data->gui, "cd_ok_button");
 	help_button = glade_xml_get_widget (data->gui, "cd_help_button");
 
 	/* Set widgets data. */
 
-#ifndef HAVE_LIBEXIF
-	gtk_widget_hide (data->cd_exif_radiobutton);
-#else /* HAVE_LIBEXIF */
 	gtk_widget_set_sensitive (data->cd_exif_radiobutton, exif_time_available (data));
-#endif /* HAVE_LIBEXIF */
 
 	gtk_widget_set_sensitive (data->cd_dateedit, gtk_toggle_button_get_active (GTK_TOGGLE_BUTTON (data->cd_following_date_radiobutton)));
 
+	update_sensitivity (data);
+
 	/* Set the signals handlers. */
 	
 	g_signal_connect (G_OBJECT (data->dialog),
@@ -229,7 +268,7 @@ dlg_change_date (GThumbWindow *window)
 				  "clicked",
 				  G_CALLBACK (gtk_widget_destroy),
 				  G_OBJECT (data->dialog));
-	g_signal_connect (G_OBJECT (ok_button), 
+	g_signal_connect (G_OBJECT (data->ok_button), 
 			  "clicked",
 			  G_CALLBACK (ok_clicked),
 			  data);
@@ -237,6 +276,15 @@ dlg_change_date (GThumbWindow *window)
 			  "clicked",
 			  G_CALLBACK (help_cb),
 			  data);
+
+	g_signal_connect (G_OBJECT (data->cd_last_modified_checkbutton), 
+			  "clicked",
+			  G_CALLBACK (radio_button_clicked),
+			  data);
+	g_signal_connect (G_OBJECT (data->cd_comment_checkbutton), 
+			  "clicked",
+			  G_CALLBACK (radio_button_clicked),
+			  data);
 	
 	g_signal_connect (G_OBJECT (data->cd_following_date_radiobutton), 
 			  "clicked",
@@ -254,11 +302,15 @@ dlg_change_date (GThumbWindow *window)
 			  "clicked",
 			  G_CALLBACK (radio_button_clicked),
 			  data);
+	g_signal_connect (G_OBJECT (data->cd_adjust_timezone_radiobutton), 
+			  "clicked",
+			  G_CALLBACK (radio_button_clicked),
+			  data);
 
 	/* Run dialog. */
 
 	gtk_window_set_transient_for (GTK_WINDOW (data->dialog), 
-				      GTK_WINDOW (window->app));
+				      GTK_WINDOW (window));
 	gtk_window_set_modal (GTK_WINDOW (data->dialog), TRUE); 
 	gtk_widget_show (data->dialog);
 }
