@@ -126,7 +126,7 @@ ok_cb (GtkWidget  *widget,
 
 static void
 save_cb (GtkWidget  *widget,
-         DialogData *data)
+	 DialogData *data)
 {
 	apply_cb (data, TRUE);
 }
@@ -134,7 +134,7 @@ save_cb (GtkWidget  *widget,
 
 static void
 help_cb (GtkWidget  *widget,
-         DialogData *data)
+	 DialogData *data)
 {
 	gthumb_display_help (GTK_WINDOW (data->dialog), "gthumb-crop");
 }
@@ -553,12 +553,10 @@ dlg_crop (GthWindow *window)
 	crop_ratio = pref_get_crop_ratio ();
 	gtk_option_menu_set_history (GTK_OPTION_MENU (data->ratio_optionmenu),
 				     crop_ratio);
-	gtk_widget_set_sensitive (data->custom_ratio_box,
-				  (crop_ratio == GTH_CROP_RATIO_CUSTOM));
-        gtk_widget_set_sensitive (data->invert_ratio_checkbutton, (crop_ratio != GTH_CROP_RATIO_NONE));
-	gth_image_selector_set_ratio (GTH_IMAGE_SELECTOR (data->image_selector),
-				      (crop_ratio != GTH_CROP_RATIO_NONE),
-				      (double) ratio_w / ratio_h);
+
+	/* Update the crop viewer with all the crop ratio settings */
+	ratio_optionmenu_changed_cb (GTK_OPTION_MENU (data->ratio_optionmenu),
+				     data);
 
 	/* Set the signals handlers. */
 
@@ -674,5 +672,6 @@ dlg_crop (GthWindow *window)
 
 	gtk_window_set_transient_for (GTK_WINDOW (data->dialog),
 				      GTK_WINDOW (window));
+	gtk_window_set_modal (GTK_WINDOW (data->dialog), TRUE);
 	gtk_widget_show (data->dialog);
 }
