@@ -49,6 +49,7 @@
 #define PREVIEW_SIZE           150
 
 typedef enum {
+	OVERWRITE_RESULT_UNSPECIFIED,
 	OVERWRITE_RESULT_YES,
 	OVERWRITE_RESULT_NO,
 	OVERWRITE_RESULT_ALL,
@@ -100,7 +101,7 @@ dlg_check_folder (GthWindow  *window,
 
 	if (! ensure_dir_exists (dir, 0755)) {
 		char *utf8_path;
-		utf8_path = g_filename_display_name (dir);
+		utf8_path = gnome_vfs_unescape_string_for_display (dir);
 		_gtk_error_dialog_run (GTK_WINDOW (window),
 				       _("Could not create folder \"%s\": %s."),
 				       utf8_path,
@@ -114,7 +115,7 @@ dlg_check_folder (GthWindow  *window,
 
 	if (! check_permissions (dir, R_OK | W_OK | X_OK)) {
 		char *utf8_path;
-		utf8_path = g_filename_display_name (dir);
+		utf8_path = gnome_vfs_unescape_string_for_display (dir);
 		_gtk_error_dialog_run (GTK_WINDOW (window),
 				       _("You don't have the right permissions to create images in the folder \"%s\""),
 				       utf8_path);
@@ -317,11 +318,7 @@ file_move_ask__continue (GnomeVFSResult result,
 	if (GTH_IS_BROWSER (window) &&
 	    gth_folder_selection_get_goto_destination (GTH_FOLDER_SELECTION (file_sel))) {
 		GthBrowser *browser = GTH_BROWSER (window);
-		char       *path;
-
-		path = gth_folder_selection_get_folder (GTH_FOLDER_SELECTION (file_sel));
-		gth_browser_go_to_directory (browser, path);
-		g_free (path);
+		gth_browser_go_to_directory (browser, gth_folder_selection_get_folder (GTH_FOLDER_SELECTION (file_sel)));
 	}
 
 	gtk_widget_destroy (GTK_WIDGET (file_sel));
@@ -345,7 +342,7 @@ file_move_response_cb (GtkWidget *w,
 
 	window = g_object_get_data (G_OBJECT (file_sel), "gthumb_window");
 	file_list = g_object_get_data (G_OBJECT (file_sel), "list");
-	path = gth_folder_selection_get_folder (GTH_FOLDER_SELECTION (file_sel));
+	path = g_strdup (gth_folder_selection_get_folder (GTH_FOLDER_SELECTION (file_sel)));
 
 	if (path == NULL)
 		return;
@@ -385,7 +382,7 @@ dlg_file_move__ask_dest (GthWindow  *window,
 	if (default_dir != NULL)
 		path = default_dir;
 	else
-		path = g_get_home_dir ();
+		path = get_home_uri ();
 
 	gth_folder_selection_set_folder (GTH_FOLDER_SELECTION (file_sel), path);
 
@@ -422,11 +419,7 @@ file_copy_ask__continue (GnomeVFSResult result,
 	if (GTH_IS_BROWSER (window) &&
 	    gth_folder_selection_get_goto_destination (GTH_FOLDER_SELECTION (file_sel))) {
 		GthBrowser *browser = GTH_BROWSER (window);
-		char       *path;
-
-		path = gth_folder_selection_get_folder (GTH_FOLDER_SELECTION (file_sel));
-		gth_browser_go_to_directory (browser, path);
-		g_free (path);
+		gth_browser_go_to_directory (browser, gth_folder_selection_get_folder (GTH_FOLDER_SELECTION (file_sel)));
 	}
 
 	gtk_widget_destroy (GTK_WIDGET (file_sel));
@@ -452,7 +445,7 @@ file_copy_response_cb (GtkWidget *w,
 
 	window = g_object_get_data (G_OBJECT (file_sel), "gthumb_window");
 	file_list = g_object_get_data (G_OBJECT (file_sel), "list");
-	path = gth_folder_selection_get_folder (GTH_FOLDER_SELECTION (file_sel));
+	path = g_strdup (gth_folder_selection_get_folder (GTH_FOLDER_SELECTION (file_sel)));
 
 	/* ignore ending slash. */
 	len = strlen (path);
@@ -489,7 +482,7 @@ dlg_file_copy__ask_dest (GthWindow  *window,
 	if (default_dir != NULL)
 		path = default_dir;
 	else
-		path = g_get_home_dir ();
+		path = get_home_uri ();
 
 	gth_folder_selection_set_folder (GTH_FOLDER_SELECTION (file_sel), path);
 
@@ -540,7 +533,7 @@ set_filename_labels (GladeXML    *gui,
 	_gtk_label_set_filename_text (GTK_LABEL (label), name);
 	g_free (name);
 
-	utf8_name = g_filename_display_name (filename);
+	utf8_name = gnome_vfs_unescape_string_for_display (filename);
 	gtk_tooltips_set_tip (tooltips, eventbox, utf8_name, NULL);
 	g_free (utf8_name);
 
@@ -629,7 +622,7 @@ create_overwrite_dialog (GthWindow         *window,
 		g_warning ("Could not find " GLADE_FILE "\n");
 		g_free (owdata);
 		return NULL;
-        }
+	}
 
 	owdata->tooltips = gtk_tooltips_new ();
 	owdata->done_func = done_func;
@@ -798,7 +791,7 @@ dlg_overwrite__response_cb (GtkWidget *dialog,
 			if (path_is_file (new_path)) {
 				char *utf8_name;
 
-				utf8_name = g_filename_display_name (new_name);
+				utf8_name = gnome_vfs_unescape_string_for_display (new_name);
 				_gtk_error_dialog_run (GTK_WINDOW (owdata->window),
 						       _("The name \"%s\" is already used in this folder. Please use a different name."),
 						       utf8_name);
@@ -899,7 +892,7 @@ dlg_overwrite_run (GthWindow     *window,
 		if (path_is_file (new_path)) {
 			char *utf8_name;
 
-			utf8_name = g_filename_display_name (*new_name);
+			utf8_name = gnome_vfs_unescape_string_for_display (*new_name);
 			_gtk_error_dialog_run (GTK_WINDOW (owdata->window),
 					       _("The name \"%s\" is already used in this folder. Please use a different name."),
 					       utf8_name);
@@ -946,18 +939,18 @@ dlg_file_rename_series (GthWindow *window,
 			GList     *old_names,
 			GList     *new_names)
 {
-	GList    *o_scan, *n_scan;
-	GList    *error_list = NULL;
-	int       overwrite_result;
-	gboolean  file_exists, show_ow_all_none;
-	gboolean  error = FALSE;
-	GList    *files_deleted = NULL;
-	GList    *files_created = NULL;
+	GList          *o_scan, *n_scan;
+	GList          *error_list = NULL;
+	int             overwrite_result = OVERWRITE_RESULT_UNSPECIFIED;
+	gboolean        file_exists, show_ow_all_none;
+	gboolean        error = FALSE;
+	GList          *files_deleted = NULL;
+	GList          *files_created = NULL;
+	GnomeVFSResult  result = GNOME_VFS_OK;
 
 	all_windows_remove_monitor ();
 
 	show_ow_all_none = g_list_length (old_names) > 1;
-	overwrite_result = OVERWRITE_RESULT_NO;
 	for (n_scan = new_names, o_scan = old_names; o_scan && n_scan;) {
 		char *old_full_path = o_scan->data;
 		char *new_full_path = n_scan->data;
@@ -977,8 +970,11 @@ dlg_file_rename_series (GthWindow *window,
 		new_full_path = g_strdup (new_full_path);
 		file_exists = path_is_file (new_full_path);
 
-		while ((overwrite_result != OVERWRITE_RESULT_ALL)
-		       && (overwrite_result != OVERWRITE_RESULT_NONE)
+		if ((overwrite_result != OVERWRITE_RESULT_ALL)
+		    && (overwrite_result != OVERWRITE_RESULT_NONE))
+			overwrite_result = OVERWRITE_RESULT_UNSPECIFIED;
+
+		while ((overwrite_result == OVERWRITE_RESULT_UNSPECIFIED)
 		       && file_exists) {
 
 			overwrite_result = dlg_overwrite_run (window,
@@ -987,6 +983,7 @@ dlg_file_rename_series (GthWindow *window,
 							      new_full_path,
 							      show_ow_all_none,
 							      &new_name);
+
 			if (overwrite_result == OVERWRITE_RESULT_RENAME) {
 				char *parent_dir;
 
@@ -994,9 +991,10 @@ dlg_file_rename_series (GthWindow *window,
 				new_full_path = g_build_path ("/", parent_dir,  new_name, NULL);
 				g_free (parent_dir);
 				g_free (new_name);
-			}
 
-			file_exists = path_is_file (new_full_path);
+				overwrite_result = OVERWRITE_RESULT_UNSPECIFIED;
+				file_exists = path_is_file (new_full_path);
+			}
 		}
 
 		if (file_exists
@@ -1008,7 +1006,8 @@ dlg_file_rename_series (GthWindow *window,
 			continue;
 		}
 
-		if (file_rename (old_full_path, new_full_path)) {
+		result = file_rename (old_full_path, new_full_path);
+		if (result == GNOME_VFS_OK) {
 			cache_move (old_full_path, new_full_path);
 			comment_move (old_full_path, new_full_path);
 
@@ -1047,7 +1046,7 @@ dlg_file_rename_series (GthWindow *window,
 		dlg_show_error (window,
 				msg,
 				error_list,
-				errno_to_string ());
+				gnome_vfs_result_to_string (result));
 	}
 
 	path_list_free (error_list);
@@ -1179,7 +1178,7 @@ continue_or_abort_dialog (FileCopyData   *fcdata,
 		error = _("Could not move the image:");
 	else
 		error = _("Could not copy the image:");
-	utf8_name = g_filename_display_basename (src_file);
+	utf8_name = basename_for_display (src_file);
 	message = g_strconcat (error,
 			       " ",
 			       utf8_name,
@@ -1363,6 +1362,9 @@ copy_current_file__overwrite (OverwriteResult  result,
 	case OVERWRITE_RESULT_NONE:
 		copy_next_file (fcdata);
 		break;
+
+	default:
+		break;
 	}
 }
 
@@ -1482,8 +1484,8 @@ copy_next_file (FileCopyData *fcdata)
 					 file_name_from_path (src_file),
 					 NULL);
 
-		src_cache_file = comments_get_comment_filename (src_file, TRUE, TRUE);
-		dest_cache_file = comments_get_comment_filename (dest_file, TRUE, TRUE);
+		src_cache_file = comments_get_comment_filename (src_file, TRUE);
+		dest_cache_file = comments_get_comment_filename (dest_file, TRUE);
 
 		if (path_is_file (src_cache_file)) {
 			char *parent_dir;
@@ -1681,7 +1683,7 @@ dlg_files_move_to_trash (GthWindow      *window,
 	if (trash_uri != NULL) {
 		char *trash_path;
 
-		trash_path = gnome_vfs_uri_to_string (trash_uri, GNOME_VFS_URI_HIDE_TOPLEVEL_METHOD);
+		trash_path = gnome_vfs_uri_to_string (trash_uri, GNOME_VFS_URI_HIDE_NONE);
 		dlg_files_copy (window,
 				file_list,
 				trash_path,
@@ -2215,11 +2217,11 @@ folder_copy (GthWindow      *window,
 	if (fcdata->include_cache) {
 		char *src_folder_comment;
 
-		src_folder_comment = comments_get_comment_filename (src_path, TRUE, TRUE);
+		src_folder_comment = comments_get_comment_filename (src_path, TRUE);
 
 		if (path_is_file (src_folder_comment)) {
 			char *dest_folder_comment;
-			dest_folder_comment = comments_get_comment_filename (dest_path, TRUE, TRUE);
+			dest_folder_comment = comments_get_comment_filename (dest_path, TRUE);
 			src_list = g_list_append (src_list, new_uri_from_path (src_folder_comment));
 			if (fcdata->file_op != FILE_OP_DELETE) {
 				if (path_is_file (dest_folder_comment))
@@ -2316,7 +2318,7 @@ dlg_folder_move_to_trash (GthWindow      *window,
 		char *trash_path;
 		char *dest_folder;
 
-		trash_path = gnome_vfs_uri_to_string (trash_uri, GNOME_VFS_URI_HIDE_TOPLEVEL_METHOD);
+		trash_path = gnome_vfs_uri_to_string (trash_uri, GNOME_VFS_URI_HIDE_NONE);
 		dest_folder = g_strconcat (trash_path, "/", file_name_from_path (folder), NULL);
 
 		folder_copy (window,
@@ -2440,7 +2442,7 @@ copy_item__continue1 (GnomeVFSResult result,
 		else
 			error = _("Could not move the folder \"%s\": %s");
 
-		utf8_name = g_filename_display_basename (folder);
+		utf8_name = basename_for_display (folder);
 		message = g_strdup_printf (error,
 					   utf8_name,
 					   gnome_vfs_result_to_string (result),
