@@ -36,20 +36,26 @@
 #include "thumb-cache.h"
 #include "comments.h"
 #include "file-utils.h"
+#include "gth-utils.h"
 #include "gtk-utils.h"
 #include "main.h"
 #include "gconf-utils.h"
-#include "gtk-utils.h"
 #include "typedefs.h"
 #include "gth-browser.h"
+#include "preferences.h"
 
 #include "icons/layout1.xpm"
 #include "icons/layout2.xpm"
 #include "icons/layout3.xpm"
 #include "icons/layout4.xpm"
 
-static gint thumb_size[] = {48, 64, 85, 95, 112, 128, 164, 200, 256};
-static gint thumb_sizes = sizeof (thumb_size) / sizeof (gint);
+static int thumb_size[] = { 48, 64, 85, 95, 112, 128, 164, 200, 256 };
+static int thumb_sizes = sizeof (thumb_size) / sizeof (int);
+static GthZoomChange zoom_change[] = { GTH_ZOOM_CHANGE_KEEP_PREV,
+				       GTH_ZOOM_CHANGE_FIT_SIZE_IF_LARGER,
+	 		               GTH_ZOOM_CHANGE_ACTUAL_SIZE,
+	 		               GTH_ZOOM_CHANGE_FIT_WIDTH_IF_LARGER };
+static int zoom_changes = sizeof (zoom_change) / sizeof (GthZoomChange);
 
 #define GLADE_PREF_FILE "gthumb_preferences.glade"
 
@@ -69,9 +75,9 @@ typedef struct {
 	GtkWidget  *radio_layout3;
 	GtkWidget  *radio_layout4;
 	GtkWidget  *toolbar_style_optionmenu;
+	GtkWidget  *radio_exif_use_orientation_tag;
+	GtkWidget  *radio_exif_use_image_transform;
 
-	GtkWidget  *view_as_slides_radiobutton;
-	GtkWidget  *view_as_list_radiobutton;
 	GtkWidget  *toggle_show_filenames;
 	GtkWidget  *toggle_show_comments;
 	GtkWidget  *toggle_show_thumbs;
@@ -86,17 +92,32 @@ typedef struct {
 	GtkWidget  *opt_zoom_change;
 	GtkWidget  *opt_transparency;
 
+	GtkWidget  *toggle_reset_scrollbars;
+
 	GtkWidget  *radio_ss_direction_forward;
 	GtkWidget  *radio_ss_direction_reverse;
 	GtkWidget  *radio_ss_direction_random;
 	GtkWidget  *spin_ss_delay;
 	GtkWidget  *toggle_ss_wrap_around;
+	GtkWidget  *toggle_ss_fading;
+
+	GtkWidget  *hotkey0;
+        GtkWidget  *hotkey1;
+        GtkWidget  *hotkey2;
+        GtkWidget  *hotkey3;
+        GtkWidget  *hotkey4;
+        GtkWidget  *hotkey5;
+        GtkWidget  *hotkey6;
+        GtkWidget  *hotkey7;
+        GtkWidget  *hotkey8;
+        GtkWidget  *hotkey9;
+
 } DialogData;
 
 
 /* called when the main dialog is closed. */
 static void
-destroy_cb (GtkWidget *widget, 
+destroy_cb (GtkWidget *widget,
 	    DialogData *data)
 {
 	g_object_unref (G_OBJECT (data->gui));
@@ -106,7 +127,7 @@ destroy_cb (GtkWidget *widget,
 
 /* called when the "apply" button is clicked. */
 static void
-apply_cb (GtkWidget  *widget, 
+apply_cb (GtkWidget  *widget,
 	  DialogData *data)
 {
 	GthDirectionType direction = GTH_DIRECTION_FORWARD;
@@ -117,13 +138,9 @@ apply_cb (GtkWidget  *widget,
 	eel_gconf_set_boolean (PREF_USE_STARTUP_LOCATION, gtk_toggle_button_get_active (GTK_TOGGLE_BUTTON (data->radio_use_startup)));
 
 	if (eel_gconf_get_boolean (PREF_USE_STARTUP_LOCATION, FALSE)) {
-		char *esc_path;
 		char *location;
 
-		esc_path = gtk_file_chooser_get_uri (GTK_FILE_CHOOSER (data->startup_dir_filechooserbutton));
-		location = gnome_vfs_unescape_string (esc_path, "");
-		g_free (esc_path);
-
+		location = gtk_file_chooser_get_uri (GTK_FILE_CHOOSER (data->startup_dir_filechooserbutton));
 		eel_gconf_set_path (PREF_STARTUP_LOCATION, location);
 		preferences_set_startup_location (location);
 		g_free (location);
@@ -132,8 +149,9 @@ apply_cb (GtkWidget  *widget,
 	/* Slide Show. */
 
 	eel_gconf_set_boolean (PREF_SLIDESHOW_WRAP_AROUND, gtk_toggle_button_get_active (GTK_TOGGLE_BUTTON (data->toggle_ss_wrap_around)));
+	eel_gconf_set_boolean (PREF_SLIDESHOW_FADING, gtk_toggle_button_get_active (GTK_TOGGLE_BUTTON (data->toggle_ss_fading)));
 
-	eel_gconf_set_integer (PREF_SLIDESHOW_DELAY, gtk_spin_button_get_value_as_int (GTK_SPIN_BUTTON (data->spin_ss_delay)));
+	eel_gconf_set_float (PREF_SLIDESHOW_DELAY, gtk_spin_button_get_value (GTK_SPIN_BUTTON (data->spin_ss_delay)));
 
 	/**/
 
@@ -145,12 +163,23 @@ apply_cb (GtkWidget  *widget,
 		direction = GTH_DIRECTION_RANDOM;
 
 	pref_set_slideshow_direction (direction);
+
+	eel_gconf_set_string (PREF_HOTKEY0, gtk_entry_get_text (GTK_ENTRY (data->hotkey0)));
+        eel_gconf_set_string (PREF_HOTKEY1, gtk_entry_get_text (GTK_ENTRY (data->hotkey1)));
+        eel_gconf_set_string (PREF_HOTKEY2, gtk_entry_get_text (GTK_ENTRY (data->hotkey2)));
+        eel_gconf_set_string (PREF_HOTKEY3, gtk_entry_get_text (GTK_ENTRY (data->hotkey3)));
+        eel_gconf_set_string (PREF_HOTKEY4, gtk_entry_get_text (GTK_ENTRY (data->hotkey4)));
+        eel_gconf_set_string (PREF_HOTKEY5, gtk_entry_get_text (GTK_ENTRY (data->hotkey5)));
+        eel_gconf_set_string (PREF_HOTKEY6, gtk_entry_get_text (GTK_ENTRY (data->hotkey6)));
+        eel_gconf_set_string (PREF_HOTKEY7, gtk_entry_get_text (GTK_ENTRY (data->hotkey7)));
+        eel_gconf_set_string (PREF_HOTKEY8, gtk_entry_get_text (GTK_ENTRY (data->hotkey8)));
+        eel_gconf_set_string (PREF_HOTKEY9, gtk_entry_get_text (GTK_ENTRY (data->hotkey9)));	
 }
 
 
 /* called when the "close" button is clicked. */
 static void
-close_cb (GtkWidget  *widget, 
+close_cb (GtkWidget  *widget,
 	  DialogData *data)
 {
 	apply_cb (widget, data);
@@ -160,40 +189,16 @@ close_cb (GtkWidget  *widget,
 
 /* called when the "help" button is clicked. */
 static void
-help_cb (GtkWidget  *widget, 
+help_cb (GtkWidget  *widget,
 	 DialogData *data)
 {
-	GError *err;
-
-	err = NULL;  
-	gnome_help_display ("gthumb", "preferences", &err);
-	
-	if (err != NULL) {
-		GtkWidget *dialog;
-		
-		dialog = gtk_message_dialog_new (GTK_WINDOW (data->dialog),
-						 0,
-						 GTK_MESSAGE_ERROR,
-						 GTK_BUTTONS_CLOSE,
-						 _("Could not display help: %s"),
-						 err->message);
-		
-		g_signal_connect (G_OBJECT (dialog), "response",
-				  G_CALLBACK (gtk_widget_destroy),
-				  NULL);
-		
-		gtk_window_set_resizable (GTK_WINDOW (dialog), FALSE);
-		
-		gtk_widget_show (dialog);
-		
-		g_error_free (err);
-	}
+	gthumb_display_help (GTK_WINDOW (data->dialog), "preferences");
 }
 
 
 /* called when the "use startup" is clicked. */
 static void
-use_startup_toggled_cb (GtkWidget *widget, 
+use_startup_toggled_cb (GtkWidget *widget,
 			DialogData *data)
 {
 	gtk_widget_set_sensitive (data->startup_dir_filechooserbutton,
@@ -205,32 +210,40 @@ use_startup_toggled_cb (GtkWidget *widget,
 
 /* called when the "set to current" button is clicked. */
 static void
-set_to_current_cb (GtkWidget  *widget, 
+set_to_current_cb (GtkWidget  *widget,
 		   DialogData *data)
 {
-	char *esc_uri;
-
-	esc_uri = gnome_vfs_escape_host_and_path_string (gth_browser_get_current_directory (data->browser));
-	gtk_file_chooser_set_uri (GTK_FILE_CHOOSER (data->startup_dir_filechooserbutton), esc_uri);
-	g_free (esc_uri);
+	gtk_file_chooser_set_uri (GTK_FILE_CHOOSER (data->startup_dir_filechooserbutton), gth_browser_get_current_directory (data->browser));
 }
 
 
 /* get the option menu index from the size value. */
-static gint
+static int
 get_idx_from_size (gint size)
 {
 	int i;
 
-	for (i = 0; i < thumb_sizes; i++) 
+	for (i = 0; i < thumb_sizes; i++)
 		if (size == thumb_size[i])
 			return i;
 	return -1;
 }
 
 
+static int
+get_idx_from_zoom_change (GthZoomChange change_mode)
+{
+	int i;
+
+	for (i = 0; i < zoom_changes; i++)
+		if (change_mode == zoom_change[i])
+			return i;
+	return -1;
+}
+
+
 static void
-layout_toggled_cb (GtkWidget *widget, 
+layout_toggled_cb (GtkWidget *widget,
 		   DialogData *data)
 {
 	int layout_type;
@@ -247,7 +260,6 @@ layout_toggled_cb (GtkWidget *widget,
 	eel_gconf_set_integer (PREF_UI_LAYOUT, layout_type);
 }
 
-
 static void
 toolbar_style_changed_cb (GtkOptionMenu *option_menu,
 			  DialogData    *data)
@@ -257,7 +269,7 @@ toolbar_style_changed_cb (GtkOptionMenu *option_menu,
 
 
 static void
-show_thumbs_toggled_cb (GtkToggleButton *button, 
+show_thumbs_toggled_cb (GtkToggleButton *button,
 			DialogData      *data)
 {
 	eel_gconf_set_boolean (PREF_SHOW_THUMBNAILS, gtk_toggle_button_get_active (GTK_TOGGLE_BUTTON (data->toggle_show_thumbs)));
@@ -265,7 +277,7 @@ show_thumbs_toggled_cb (GtkToggleButton *button,
 
 
 static void
-show_filenames_toggled_cb (GtkToggleButton *button, 
+show_filenames_toggled_cb (GtkToggleButton *button,
 			   DialogData      *data)
 {
 	eel_gconf_set_boolean (PREF_SHOW_FILENAMES, gtk_toggle_button_get_active (GTK_TOGGLE_BUTTON (data->toggle_show_filenames)));
@@ -273,33 +285,13 @@ show_filenames_toggled_cb (GtkToggleButton *button,
 
 
 static void
-show_comments_toggled_cb (GtkToggleButton *button, 
+show_comments_toggled_cb (GtkToggleButton *button,
 			  DialogData      *data)
 {
 	eel_gconf_set_boolean (PREF_SHOW_COMMENTS, gtk_toggle_button_get_active (GTK_TOGGLE_BUTTON (data->toggle_show_comments)));
 }
 
 
-static void
-view_as_slides_toggled_cb (GtkToggleButton *button, 
-			   DialogData      *data)
-{
-	if (! gtk_toggle_button_get_active (button))
-		return;
-	pref_set_view_as (GTH_VIEW_AS_THUMBNAILS);
-}
-
-
-static void
-view_as_list_toggled_cb (GtkToggleButton *button, 
-			 DialogData      *data)
-{
-	if (! gtk_toggle_button_get_active (button))
-		return;
-	pref_set_view_as (GTH_VIEW_AS_LIST);
-}
-
-
 static void
 thumbs_size_changed_cb (GtkOptionMenu *option_menu,
 			DialogData    *data)
@@ -320,7 +312,7 @@ click_policy_changed_cb (GtkOptionMenu *option_menu,
 
 
 static void
-confirm_del_toggled_cb (GtkToggleButton *button, 
+confirm_del_toggled_cb (GtkToggleButton *button,
 			DialogData      *data)
 {
 	eel_gconf_set_boolean (PREF_CONFIRM_DELETION, gtk_toggle_button_get_active (GTK_TOGGLE_BUTTON (data->toggle_confirm_del)));
@@ -328,7 +320,7 @@ confirm_del_toggled_cb (GtkToggleButton *button,
 
 
 static void
-ask_to_save_toggled_cb (GtkToggleButton *button, 
+ask_to_save_toggled_cb (GtkToggleButton *button,
 			DialogData      *data)
 {
 	eel_gconf_set_boolean (PREF_MSG_SAVE_MODIFIED_IMAGE, gtk_toggle_button_get_active (GTK_TOGGLE_BUTTON (data->toggle_ask_to_save)));
@@ -336,7 +328,7 @@ ask_to_save_toggled_cb (GtkToggleButton *button,
 
 
 static void
-fast_file_type_toggled_cb (GtkToggleButton *button, 
+fast_file_type_toggled_cb (GtkToggleButton *button,
 			   DialogData      *data)
 {
 	eel_gconf_set_boolean (PREF_FAST_FILE_TYPE, ! gtk_toggle_button_get_active (GTK_TOGGLE_BUTTON (data->toggle_file_type)));
@@ -344,7 +336,7 @@ fast_file_type_toggled_cb (GtkToggleButton *button,
 
 
 static void
-zoom_quality_high_cb (GtkToggleButton *button, 
+zoom_quality_high_cb (GtkToggleButton *button,
 		      DialogData      *data)
 {
 	if (! gtk_toggle_button_get_active (button))
@@ -354,7 +346,7 @@ zoom_quality_high_cb (GtkToggleButton *button,
 
 
 static void
-zoom_quality_low_cb (GtkToggleButton *button, 
+zoom_quality_low_cb (GtkToggleButton *button,
 		     DialogData      *data)
 {
 	if (! gtk_toggle_button_get_active (button))
@@ -364,15 +356,24 @@ zoom_quality_low_cb (GtkToggleButton *button,
 
 
 static void
-zoom_change_changed_cb (GtkOptionMenu *option_menu, 
+zoom_change_changed_cb (GtkOptionMenu *option_menu,
 			DialogData    *data)
 {
-	pref_set_zoom_change (gtk_option_menu_get_history (GTK_OPTION_MENU (data->opt_zoom_change)));
+	int idx = gtk_option_menu_get_history (GTK_OPTION_MENU (data->opt_zoom_change));
+	pref_set_zoom_change (zoom_change[idx]);
 }
 
 
 static void
-transp_type_changed_cb (GtkOptionMenu *option_menu, 
+reset_scrollbars_toggled_cb (GtkToggleButton *button,
+			     DialogData      *data)
+{
+	eel_gconf_set_boolean (PREF_RESET_SCROLLBARS, gtk_toggle_button_get_active (GTK_TOGGLE_BUTTON (data->toggle_reset_scrollbars)));
+}
+
+
+static void
+transp_type_changed_cb (GtkOptionMenu *option_menu,
 			DialogData    *data)
 {
 	pref_set_transp_type(gtk_option_menu_get_history (GTK_OPTION_MENU (data->opt_transparency)));
@@ -393,7 +394,7 @@ dlg_preferences (GthBrowser *browser)
 	char             *startup_location;
 	GthDirectionType  direction;
 
-	data = g_new (DialogData, 1);
+	data = g_new0 (DialogData, 1);
 	data->browser = browser;
 	data->gui = glade_xml_new (GTHUMB_GLADEDIR "/" GLADE_PREF_FILE, NULL, NULL);
         if (!data->gui) {
@@ -422,9 +423,8 @@ dlg_preferences (GthBrowser *browser)
 	data->radio_layout3 = glade_xml_get_widget (data->gui, "radio_layout3");
 	data->radio_layout4 = glade_xml_get_widget (data->gui, "radio_layout4");
 	data->toolbar_style_optionmenu = glade_xml_get_widget (data->gui, "toolbar_style_optionmenu");
-
-	data->view_as_slides_radiobutton = glade_xml_get_widget (data->gui, "view_as_slides_radiobutton");
-	data->view_as_list_radiobutton = glade_xml_get_widget (data->gui, "view_as_list_radiobutton");
+	data->radio_exif_use_orientation_tag = glade_xml_get_widget (data->gui, "radio_exif_use_orientation_tag");
+	data->radio_exif_use_image_transform = glade_xml_get_widget (data->gui, "radio_exif_use_image_transform");
 
         data->toggle_show_filenames = glade_xml_get_widget (data->gui, "toggle_show_filenames");
         data->toggle_show_comments = glade_xml_get_widget (data->gui, "toggle_show_comments");
@@ -440,11 +440,25 @@ dlg_preferences (GthBrowser *browser)
         data->opt_zoom_change = glade_xml_get_widget (data->gui, "opt_zoom_change");
 	data->opt_transparency = glade_xml_get_widget (data->gui, "opt_transparency");
 
+	data->toggle_reset_scrollbars = glade_xml_get_widget (data->gui, "toggle_reset_scrollbars");
+
         data->radio_ss_direction_forward = glade_xml_get_widget (data->gui, "radio_ss_direction_forward");
         data->radio_ss_direction_reverse = glade_xml_get_widget (data->gui, "radio_ss_direction_reverse");
         data->radio_ss_direction_random = glade_xml_get_widget (data->gui, "radio_ss_direction_random");
         data->spin_ss_delay = glade_xml_get_widget (data->gui, "spin_ss_delay");
         data->toggle_ss_wrap_around = glade_xml_get_widget (data->gui, "toggle_ss_wrap_around");
+        data->toggle_ss_fading = glade_xml_get_widget (data->gui, "toggle_ss_fading");
+
+	data->hotkey0 = glade_xml_get_widget (data->gui, "hotkey0");
+        data->hotkey1 = glade_xml_get_widget (data->gui, "hotkey1");
+        data->hotkey2 = glade_xml_get_widget (data->gui, "hotkey2");
+        data->hotkey3 = glade_xml_get_widget (data->gui, "hotkey3");
+        data->hotkey4 = glade_xml_get_widget (data->gui, "hotkey4");
+        data->hotkey5 = glade_xml_get_widget (data->gui, "hotkey5");
+        data->hotkey6 = glade_xml_get_widget (data->gui, "hotkey6");
+        data->hotkey7 = glade_xml_get_widget (data->gui, "hotkey7");
+        data->hotkey8 = glade_xml_get_widget (data->gui, "hotkey8");
+        data->hotkey9 = glade_xml_get_widget (data->gui, "hotkey9");
 
 	btn_close  = glade_xml_get_widget (data->gui, "p_close_button");
 	btn_help   = glade_xml_get_widget (data->gui, "p_help_button");
@@ -457,26 +471,18 @@ dlg_preferences (GthBrowser *browser)
 		gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (data->radio_use_startup), TRUE);
 	else if (eel_gconf_get_boolean (PREF_GO_TO_LAST_LOCATION, TRUE))
 		gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (data->radio_last_location), TRUE);
-	else 
+	else
 		gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (data->radio_current_location), TRUE);
-	
+
 	if (! eel_gconf_get_boolean (PREF_USE_STARTUP_LOCATION, FALSE)) {
 		gtk_widget_set_sensitive (data->startup_dir_filechooserbutton, FALSE);
 		gtk_widget_set_sensitive (data->btn_set_to_current, FALSE);
 	}
 
 	startup_location = eel_gconf_get_path (PREF_STARTUP_LOCATION, NULL);
-	
-	if ((startup_location != NULL)
-	    && pref_util_location_is_file (startup_location)) {
-		const char *uri;
-		char       *esc_uri;
 
-		uri = pref_util_get_file_location (startup_location);
-		esc_uri = gnome_vfs_escape_host_and_path_string (uri);
-		gtk_file_chooser_set_uri (GTK_FILE_CHOOSER (data->startup_dir_filechooserbutton), esc_uri);
-		g_free (esc_uri);
-	}
+	if (uri_scheme_is_file (startup_location))
+		gtk_file_chooser_set_uri (GTK_FILE_CHOOSER (data->startup_dir_filechooserbutton), startup_location);
 
 	g_free (startup_location);
 
@@ -508,11 +514,6 @@ dlg_preferences (GthBrowser *browser)
 
 	/* * browser */
 
-	if (pref_get_view_as () == GTH_VIEW_AS_THUMBNAILS)
-		gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (data->view_as_slides_radiobutton), TRUE);
-	else
-		gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (data->view_as_list_radiobutton), TRUE);
-
 	gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (data->toggle_file_type), ! eel_gconf_get_boolean (PREF_FAST_FILE_TYPE, TRUE));
 	gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (data->toggle_show_filenames), eel_gconf_get_boolean (PREF_SHOW_FILENAMES, FALSE));
 	gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (data->toggle_show_comments), eel_gconf_get_boolean (PREF_SHOW_COMMENTS, TRUE));
@@ -527,9 +528,11 @@ dlg_preferences (GthBrowser *browser)
 	else
 		gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (data->opt_zoom_quality_low), TRUE);
 
-	gtk_option_menu_set_history (GTK_OPTION_MENU (data->opt_zoom_change), pref_get_zoom_change ());
+	gtk_option_menu_set_history (GTK_OPTION_MENU (data->opt_zoom_change), get_idx_from_zoom_change (pref_get_zoom_change ()));
 	gtk_option_menu_set_history (GTK_OPTION_MENU (data->opt_transparency), image_viewer_get_transp_type (gth_window_get_image_viewer (GTH_WINDOW (browser))));
 
+	gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (data->toggle_reset_scrollbars), eel_gconf_get_boolean (PREF_RESET_SCROLLBARS, TRUE));
+
 	/* * slide show */
 
 	direction = pref_get_slideshow_direction ();
@@ -539,81 +542,102 @@ dlg_preferences (GthBrowser *browser)
 		gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (data->radio_ss_direction_reverse), TRUE);
 	else
 		gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (data->radio_ss_direction_random), TRUE);
-		
+
 	gtk_spin_button_set_value (GTK_SPIN_BUTTON (data->spin_ss_delay),
-				   (gfloat) eel_gconf_get_integer (PREF_SLIDESHOW_DELAY, 4));
+				   eel_gconf_get_float (PREF_SLIDESHOW_DELAY, 4.0));
 	gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (data->toggle_ss_wrap_around), eel_gconf_get_boolean (PREF_SLIDESHOW_WRAP_AROUND, FALSE));
+	gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (data->toggle_ss_fading), eel_gconf_get_boolean (PREF_SLIDESHOW_FADING, TRUE));
+
+	gtk_entry_set_text (GTK_ENTRY (data->hotkey0), 
+			    eel_gconf_get_string (PREF_HOTKEY0, 
+			    "gimp-remote %F"));
+
+	gtk_entry_set_text (GTK_ENTRY (data->hotkey1), 
+			    eel_gconf_get_string (PREF_HOTKEY1, 
+			    "convert %f -font Helvetica -pointsize 20 -fill white  -box '#00000080'  -gravity South -annotate +0+5 ' Copyright 2007, Your Name Here ' %n-copyright%e"));
+
+        gtk_entry_set_text (GTK_ENTRY (data->hotkey2), 
+			    eel_gconf_get_string (PREF_HOTKEY2, 
+			    "mkdir -p %p/approved ; cp %f %p/approved/"));
+
+        gtk_entry_set_text (GTK_ENTRY (data->hotkey3), 
+			    eel_gconf_get_string (PREF_HOTKEY3, 
+			    "uuencode %f %f | mail -s Photos your@emailaddress.com"));
+
+        gtk_entry_set_text (GTK_ENTRY (data->hotkey4), 
+			    eel_gconf_get_string (PREF_HOTKEY4, 
+			    "rm ~/myarchive.zip; zip -j ~/myarchive %F"));
+
+        gtk_entry_set_text (GTK_ENTRY (data->hotkey5), 
+			    eel_gconf_get_string (PREF_HOTKEY5, 
+		 	    "rm ~/myarchive.zip; zip -j ~/myarchive %F; uuencode ~/myarchive.zip ~/myarchive.zip | mail -s Photos your@emailaddress.com"));
+
+        gtk_entry_set_text (GTK_ENTRY (data->hotkey6), eel_gconf_get_string (PREF_HOTKEY6, ""));
+        gtk_entry_set_text (GTK_ENTRY (data->hotkey7), eel_gconf_get_string (PREF_HOTKEY7, ""));
+        gtk_entry_set_text (GTK_ENTRY (data->hotkey8), eel_gconf_get_string (PREF_HOTKEY8, ""));
+        gtk_entry_set_text (GTK_ENTRY (data->hotkey9), eel_gconf_get_string (PREF_HOTKEY9, ""));
 
 	/* Set the signals handlers. */
 
-	g_signal_connect (G_OBJECT (data->dialog), 
+	g_signal_connect (G_OBJECT (data->dialog),
 			  "destroy",
 			  G_CALLBACK (destroy_cb),
 			  data);
 
-	g_signal_connect (G_OBJECT (btn_close), 
+	g_signal_connect (G_OBJECT (btn_close),
 			  "clicked",
 			  G_CALLBACK (close_cb),
 			  data);
-	g_signal_connect (G_OBJECT (btn_help), 
+	g_signal_connect (G_OBJECT (btn_help),
 			  "clicked",
 			  G_CALLBACK (help_cb),
 			  data);
 
-	g_signal_connect (G_OBJECT (data->radio_use_startup), 
+	g_signal_connect (G_OBJECT (data->radio_use_startup),
 			  "toggled",
 			  G_CALLBACK (use_startup_toggled_cb),
 			  data);
-	g_signal_connect (G_OBJECT (data->btn_set_to_current), 
+	g_signal_connect (G_OBJECT (data->btn_set_to_current),
 			  "clicked",
 			  G_CALLBACK (set_to_current_cb),
 			  data);
 
 	/**/
 
-	g_signal_connect (G_OBJECT (data->radio_layout1), 
+	g_signal_connect (G_OBJECT (data->radio_layout1),
 			  "toggled",
 			  G_CALLBACK (layout_toggled_cb),
 			  data);
-	g_signal_connect (G_OBJECT (data->radio_layout2), 
+	g_signal_connect (G_OBJECT (data->radio_layout2),
 			  "toggled",
 			  G_CALLBACK (layout_toggled_cb),
 			  data);
-	g_signal_connect (G_OBJECT (data->radio_layout3), 
+	g_signal_connect (G_OBJECT (data->radio_layout3),
 			  "toggled",
 			  G_CALLBACK (layout_toggled_cb),
 			  data);
-	g_signal_connect (G_OBJECT (data->radio_layout4), 
+	g_signal_connect (G_OBJECT (data->radio_layout4),
 			  "toggled",
 			  G_CALLBACK (layout_toggled_cb),
 			  data);
 
-	g_signal_connect (G_OBJECT (data->toolbar_style_optionmenu), 
+	g_signal_connect (G_OBJECT (data->toolbar_style_optionmenu),
 			  "changed",
 			  G_CALLBACK (toolbar_style_changed_cb),
 			  data);
-	g_signal_connect (G_OBJECT (data->toggle_show_thumbs), 
+	g_signal_connect (G_OBJECT (data->toggle_show_thumbs),
 			  "toggled",
 			  G_CALLBACK (show_thumbs_toggled_cb),
 			  data);
-	g_signal_connect (G_OBJECT (data->toggle_show_filenames), 
+	g_signal_connect (G_OBJECT (data->toggle_show_filenames),
 			  "toggled",
 			  G_CALLBACK (show_filenames_toggled_cb),
 			  data);
-	g_signal_connect (G_OBJECT (data->toggle_show_comments), 
+	g_signal_connect (G_OBJECT (data->toggle_show_comments),
 			  "toggled",
 			  G_CALLBACK (show_comments_toggled_cb),
 			  data);
 
-	g_signal_connect (G_OBJECT (data->view_as_slides_radiobutton), 
-			  "toggled",
-			  G_CALLBACK (view_as_slides_toggled_cb),
-			  data);
-	g_signal_connect (G_OBJECT (data->view_as_list_radiobutton), 
-			  "toggled",
-			  G_CALLBACK (view_as_list_toggled_cb),
-			  data);
-
 	g_signal_connect (G_OBJECT (data->opt_thumbs_size),
 			  "changed",
 			  G_CALLBACK (thumbs_size_changed_cb),
@@ -623,24 +647,24 @@ dlg_preferences (GthBrowser *browser)
 			  "changed",
 			  G_CALLBACK (click_policy_changed_cb),
 			  data);
-	g_signal_connect (G_OBJECT (data->toggle_confirm_del), 
+	g_signal_connect (G_OBJECT (data->toggle_confirm_del),
 			  "toggled",
 			  G_CALLBACK (confirm_del_toggled_cb),
 			  data);
-	g_signal_connect (G_OBJECT (data->toggle_ask_to_save), 
+	g_signal_connect (G_OBJECT (data->toggle_ask_to_save),
 			  "toggled",
 			  G_CALLBACK (ask_to_save_toggled_cb),
 			  data);
-	g_signal_connect (G_OBJECT (data->toggle_file_type), 
+	g_signal_connect (G_OBJECT (data->toggle_file_type),
 			  "toggled",
 			  G_CALLBACK (fast_file_type_toggled_cb),
 			  data);
 
-	g_signal_connect (G_OBJECT (data->opt_zoom_quality_high), 
+	g_signal_connect (G_OBJECT (data->opt_zoom_quality_high),
 			  "toggled",
 			  G_CALLBACK (zoom_quality_high_cb),
 			  data);
-	g_signal_connect (G_OBJECT (data->opt_zoom_quality_low), 
+	g_signal_connect (G_OBJECT (data->opt_zoom_quality_low),
 			  "toggled",
 			  G_CALLBACK (zoom_quality_low_cb),
 			  data);
@@ -652,10 +676,14 @@ dlg_preferences (GthBrowser *browser)
 			  "changed",
 			  G_CALLBACK (transp_type_changed_cb),
 			  data);
+        g_signal_connect (G_OBJECT (data->toggle_reset_scrollbars),
+                          "toggled",
+                          G_CALLBACK (reset_scrollbars_toggled_cb),
+                          data);
 
 	/* run dialog. */
 
-	gtk_window_set_transient_for (GTK_WINDOW (data->dialog), 
+	gtk_window_set_transient_for (GTK_WINDOW (data->dialog),
 				      GTK_WINDOW (browser));
 	gtk_window_set_modal (GTK_WINDOW (data->dialog), FALSE);
 	gtk_widget_show_all (data->dialog);
