@@ -22,11 +22,11 @@
 
 #include <config.h>
 #include <string.h>
-
+#include <strings.h>
 #include <glib/gi18n.h>
 #include <libgnomevfs/gnome-vfs-types.h>
 #include <libgnomevfs/gnome-vfs-async-ops.h>
-
+#include <libgnomevfs/gnome-vfs-utils.h>
 #include "typedefs.h"
 #include "gth-dir-list.h"
 #include "gth-file-list.h"
@@ -45,7 +45,7 @@
 enum {
 	DIR_LIST_COLUMN_ICON,
 	DIR_LIST_COLUMN_NAME,
-	DIR_LIST_COLUMN_UTF_NAME,
+	DIR_LIST_COLUMN_DISPLAY_NAME,
 	DIR_LIST_NUM_COLUMNS
 };
 
@@ -120,7 +120,7 @@ filename_cell_data_func (GtkTreeViewColumn *column,
 	PangoUnderline  underline;
 
 	gtk_tree_model_get (model, iter,
-			    DIR_LIST_COLUMN_UTF_NAME, &text,
+			    DIR_LIST_COLUMN_DISPLAY_NAME, &text,
 			    -1);
 
 	if (dir_list->single_click) {
@@ -175,11 +175,11 @@ add_columns (GthDirList  *dir_list,
                                          renderer,
                                          TRUE);
         gtk_tree_view_column_set_attributes (column, renderer,
-                                             "text", DIR_LIST_COLUMN_UTF_NAME,
+                                             "text", DIR_LIST_COLUMN_DISPLAY_NAME,
                                              NULL);
 
         gtk_tree_view_column_set_sizing (column, GTK_TREE_VIEW_COLUMN_AUTOSIZE);
-	gtk_tree_view_column_set_sort_column_id (column, DIR_LIST_COLUMN_UTF_NAME);
+	gtk_tree_view_column_set_sort_column_id (column, DIR_LIST_COLUMN_DISPLAY_NAME);
 	gtk_tree_view_column_set_cell_data_func (column, renderer,
 						 (GtkTreeCellDataFunc) filename_cell_data_func,
 						 dir_list, NULL);
@@ -306,7 +306,7 @@ gth_dir_list_init (GthDirList *dir_list)
         add_columns (dir_list, list_view);
 	gtk_tree_view_set_headers_visible (list_view, FALSE);
         gtk_tree_view_set_enable_search (list_view, TRUE);
-        gtk_tree_view_set_search_column (list_view, DIR_LIST_COLUMN_UTF_NAME);
+        gtk_tree_view_set_search_column (list_view, DIR_LIST_COLUMN_DISPLAY_NAME);
 
 	g_signal_connect (G_OBJECT (list_view),
 			  "motion_notify_event",
@@ -426,11 +426,11 @@ gth_dir_list_update_view (GthDirList *dir_list)
 		else
 			pixbuf = dir_pixbuf;
 
-		utf8_name = g_filename_display_name (name);
+		utf8_name = gnome_vfs_unescape_string_for_display (name);
 		gtk_list_store_append (dir_list->list_store, &iter);
 		gtk_list_store_set (dir_list->list_store, &iter,
 				    DIR_LIST_COLUMN_ICON, pixbuf,
-				    DIR_LIST_COLUMN_UTF_NAME, utf8_name,
+				    DIR_LIST_COLUMN_DISPLAY_NAME, utf8_name,
 				    DIR_LIST_COLUMN_NAME, name,
 				    -1);
 
@@ -451,7 +451,7 @@ gth_dir_list_update_icon_theme (GthDirList *dir_list)
 
 
 static void
-gth_dir_list_change_to__step3 (PathListData *pld,
+gth_dir_list_change_to__step2 (PathListData *pld,
 			       gpointer      data)
 {
 	GthDirList *dir_list = data;
@@ -459,8 +459,7 @@ gth_dir_list_change_to__step3 (PathListData *pld,
 	GList      *new_file_list = NULL;
 	GList      *filtered;
 
-	if (pld == NULL)
-		return;
+	g_return_if_fail (pld != NULL);
 
 	dir_list = data;
 
@@ -576,14 +575,6 @@ gth_dir_list_change_to__step3 (PathListData *pld,
 }
 
 
-static void
-gth_dir_list_change_to__step2 (gpointer callback_data)
-{
-	GthDirList *dir_list = callback_data;
-	dir_list->dir_load_handle = path_list_async_new (dir_list->try_path, gth_dir_list_change_to__step3, dir_list);
-}
-
-
 void
 gth_dir_list_change_to (GthDirList *dir_list,
 		        const char *path)
@@ -597,9 +588,9 @@ gth_dir_list_change_to (GthDirList *dir_list,
 	dir_list->try_path = remove_ending_separator (path);
 
 	if (dir_list->dir_load_handle != NULL)
-		path_list_async_interrupt (dir_list->dir_load_handle, gth_dir_list_change_to__step2, dir_list);
-	else
-		dir_list->dir_load_handle = path_list_async_new (dir_list->try_path, gth_dir_list_change_to__step3, dir_list);
+		path_list_async_interrupt (dir_list->dir_load_handle, NULL, NULL);
+
+	dir_list->dir_load_handle = path_list_async_new (dir_list->try_path, gth_dir_list_change_to__step2, dir_list);
 }
 
 
@@ -664,11 +655,11 @@ gth_dir_list_add_directory (GthDirList *dir_list,
 	else
 		pixbuf = dir_pixbuf;
 
-	utf8_name = g_filename_display_name (name_only);
+	utf8_name = gnome_vfs_unescape_string_for_display (name_only);
 	gtk_list_store_insert (dir_list->list_store, &iter, pos);
 	gtk_list_store_set (dir_list->list_store, &iter,
 			    DIR_LIST_COLUMN_ICON, pixbuf,
-			    DIR_LIST_COLUMN_UTF_NAME, utf8_name,
+			    DIR_LIST_COLUMN_DISPLAY_NAME, utf8_name,
 			    DIR_LIST_COLUMN_NAME, name_only,
 			    -1);
 	g_free (utf8_name);
@@ -730,7 +721,7 @@ gth_dir_list_get_name_from_iter (GthDirList  *dir_list,
 
 	gtk_tree_model_get (GTK_TREE_MODEL (dir_list->list_store),
 			    iter,
-			    DIR_LIST_COLUMN_UTF_NAME, &utf8_name,
+			    DIR_LIST_COLUMN_DISPLAY_NAME, &utf8_name,
 			    -1);
 
 	return utf8_name;
